hexsha stringlengths 40 40 | size int64 1 1.03M | ext stringclasses 10
values | lang stringclasses 1
value | max_stars_repo_path stringlengths 3 239 | max_stars_repo_name stringlengths 5 130 | max_stars_repo_head_hexsha stringlengths 40 78 | max_stars_repo_licenses listlengths 1 10 | max_stars_count int64 1 191k ⌀ | max_stars_repo_stars_event_min_datetime stringlengths 24 24 ⌀ | max_stars_repo_stars_event_max_datetime stringlengths 24 24 ⌀ | max_issues_repo_path stringlengths 3 239 | max_issues_repo_name stringlengths 5 130 | max_issues_repo_head_hexsha stringlengths 40 78 | max_issues_repo_licenses listlengths 1 10 | max_issues_count int64 1 67k ⌀ | max_issues_repo_issues_event_min_datetime stringlengths 24 24 ⌀ | max_issues_repo_issues_event_max_datetime stringlengths 24 24 ⌀ | max_forks_repo_path stringlengths 3 239 | max_forks_repo_name stringlengths 5 130 | max_forks_repo_head_hexsha stringlengths 40 78 | max_forks_repo_licenses listlengths 1 10 | max_forks_count int64 1 105k ⌀ | max_forks_repo_forks_event_min_datetime stringlengths 24 24 ⌀ | max_forks_repo_forks_event_max_datetime stringlengths 24 24 ⌀ | content stringlengths 1 1.03M | avg_line_length float64 1 958k | max_line_length int64 1 1.03M | alphanum_fraction float64 0 1 |
|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|
796693dad50979bb396f74488b994a916e901476 | 1,766 | py | Python | setup.py | 7pairs/pyny | cf4ad9a5955207f99eb1beb7bcd6fc0cfa8e4fb8 | [
"Apache-2.0"
] | null | null | null | setup.py | 7pairs/pyny | cf4ad9a5955207f99eb1beb7bcd6fc0cfa8e4fb8 | [
"Apache-2.0"
] | 50 | 2015-03-01T11:53:00.000Z | 2021-12-22T12:01:32.000Z | setup.py | 7pairs/pyny | cf4ad9a5955207f99eb1beb7bcd6fc0cfa8e4fb8 | [
"Apache-2.0"
] | null | null | null | # -*- coding: utf-8 -*-
#
# Copyright 2015-2019 Jun-ya HASEBA
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applic... | 31.535714 | 74 | 0.677803 |
7966946bab65e7e0e073fc6d823f22bc192f5b49 | 134 | py | Python | bitswap/__init__.py | AliabbasMerchant/py-bitswap | d27826f93b340e76970e7f1e91d52e02749dd2ca | [
"MIT"
] | null | null | null | bitswap/__init__.py | AliabbasMerchant/py-bitswap | d27826f93b340e76970e7f1e91d52e02749dd2ca | [
"MIT"
] | 2 | 2019-10-28T12:26:03.000Z | 2020-02-02T18:28:46.000Z | bitswap/__init__.py | AliabbasMerchant/py-ipfs-bitswap | d27826f93b340e76970e7f1e91d52e02749dd2ca | [
"MIT"
] | 2 | 2019-10-29T16:33:52.000Z | 2020-11-18T14:15:09.000Z | """Python implementation of the Bitswap 'data exchange' protocol used by IPFS"""
__version__ = '0.0.1'
from .IPFSBlock import Block
| 22.333333 | 80 | 0.746269 |
7966953b20e6f931767a325c12748dcebe9e336f | 230 | py | Python | venv/Lib/site-packages/imgurpython/imgur/models/notification.py | The-Fragment/FragmentFembot | bca0027b423753eb162590e8fd440a2c1e65d133 | [
"MIT"
] | 560 | 2015-01-01T15:06:39.000Z | 2022-03-19T04:05:20.000Z | venv/Lib/site-packages/imgurpython/imgur/models/notification.py | The-Fragment/FragmentFembot | bca0027b423753eb162590e8fd440a2c1e65d133 | [
"MIT"
] | 58 | 2015-01-30T10:20:32.000Z | 2021-07-24T18:56:04.000Z | venv/Lib/site-packages/imgurpython/imgur/models/notification.py | The-Fragment/FragmentFembot | bca0027b423753eb162590e8fd440a2c1e65d133 | [
"MIT"
] | 168 | 2015-01-20T01:26:00.000Z | 2022-03-21T01:43:51.000Z | class Notification(object):
def __init__(self, notification_id, account_id, viewed, content):
self.id = notification_id
self.account_id = account_id
self.viewed = viewed
self.content = content
| 28.75 | 69 | 0.673913 |
796695b1367ead7bb6db890baf0b40d4e1647d12 | 45,407 | py | Python | src/run_classifier.py | takanobu-watanabe/bert-japanese | c4ccf65c01f515b6de9ddece7b04c8bd61a4a262 | [
"Apache-2.0"
] | null | null | null | src/run_classifier.py | takanobu-watanabe/bert-japanese | c4ccf65c01f515b6de9ddece7b04c8bd61a4a262 | [
"Apache-2.0"
] | null | null | null | src/run_classifier.py | takanobu-watanabe/bert-japanese | c4ccf65c01f515b6de9ddece7b04c8bd61a4a262 | [
"Apache-2.0"
] | null | null | null | # coding=utf-8
# This file is based on https://github.com/google-research/bert/blob/master/run_classifier.py.
# It is changed to use SentencePiece tokenizer and https://www.rondhuit.com/download/ldcc-20140209.tar.gz.
"""BERT finetuning runner."""
from __future__ import absolute_import
from __future__ import division
f... | 50.396226 | 13,189 | 0.619398 |
79669728b6dfad55ce77f2e8cba4d6301a62b908 | 17,274 | py | Python | training/stylegan_lightning.py | denix56/stylegan2-ada-pytorch | 9df6a704a5dd1db779966307422b70c293b393fc | [
"BSD-Source-Code"
] | 1 | 2021-02-24T19:24:04.000Z | 2021-02-24T19:24:04.000Z | training/stylegan_lightning.py | denix56/stylegan2-ada-pytorch | 9df6a704a5dd1db779966307422b70c293b393fc | [
"BSD-Source-Code"
] | null | null | null | training/stylegan_lightning.py | denix56/stylegan2-ada-pytorch | 9df6a704a5dd1db779966307422b70c293b393fc | [
"BSD-Source-Code"
] | null | null | null | import torch
import torch.nn as nn
import torch.nn.functional as F
import pytorch_lightning as pl
import dnnlib
import copy
import numpy as np
from torch_utils.ops import conv2d_gradfix
from functools import partial
from torch_utils import misc
from .metrics_lightning import StyleGANMetric
from .dataloader_lightning im... | 46.310992 | 134 | 0.618675 |
7966979d216345e2629d02e3b2c926f89ec9abae | 1,226 | py | Python | examples/ros/gibson-ros/turtlebot_nonviz.py | rainprob/GibsonEnv | e0d0bc614713c676cb303bf9f11ca6a98713e0e0 | [
"MIT"
] | 731 | 2018-02-26T18:35:05.000Z | 2022-03-23T04:00:09.000Z | examples/ros/gibson-ros/turtlebot_nonviz.py | Shubodh/GibsonEnv | 38274874d7c2c2a87efdb6ee529f2b366c5219de | [
"MIT"
] | 111 | 2018-04-19T01:00:22.000Z | 2022-03-18T17:43:50.000Z | examples/ros/gibson-ros/turtlebot_nonviz.py | Shubodh/GibsonEnv | 38274874d7c2c2a87efdb6ee529f2b366c5219de | [
"MIT"
] | 153 | 2018-02-27T04:38:40.000Z | 2022-03-28T08:10:39.000Z | #!/usr/bin/python
from gibson.envs.mobile_robots_env import TurtlebotNavigateEnv
from gibson.utils.play import play
import argparse
import os
import rospy
from std_msgs.msg import Float32, Int64
from geometry_msgs.msg import Twist
import rospkg
import numpy as np
import gym
#import pygame
import sys
import time
import... | 22.703704 | 67 | 0.764274 |
796697c3f5abc629750887fe9c81169fa21d96c3 | 2,810 | py | Python | tests/syft/core/pointer/pointer_test.py | aeroaks/PySyft | 88220c38faf3cd72ddc63c73f3c0533695df53c9 | [
"Apache-2.0"
] | null | null | null | tests/syft/core/pointer/pointer_test.py | aeroaks/PySyft | 88220c38faf3cd72ddc63c73f3c0533695df53c9 | [
"Apache-2.0"
] | null | null | null | tests/syft/core/pointer/pointer_test.py | aeroaks/PySyft | 88220c38faf3cd72ddc63c73f3c0533695df53c9 | [
"Apache-2.0"
] | null | null | null | # third party
import pytest
import torch as th
# syft absolute
import syft as sy
@pytest.mark.parametrize("with_verify_key", [True, False])
def test_make_searchable(with_verify_key: bool) -> None:
bob = sy.VirtualMachine(name="Bob")
root_client = bob.get_root_client()
client = bob.get_client()
ten =... | 25.545455 | 87 | 0.659786 |
796697ca3b97255cb595b2185f3eae82af9cbbb3 | 1,047 | py | Python | core/commands/jobs.py | AJMartel/koadic | a22d164bb2873f4782e8512d847493579c0c77eb | [
"Apache-2.0"
] | 3 | 2019-09-25T04:31:22.000Z | 2022-02-26T06:36:58.000Z | core/commands/jobs.py | khast3x/koadic | 45a8c52d0a439314616b2bc7572d5602c13b5f5f | [
"Apache-2.0"
] | null | null | null | core/commands/jobs.py | khast3x/koadic | 45a8c52d0a439314616b2bc7572d5602c13b5f5f | [
"Apache-2.0"
] | 1 | 2020-03-20T03:52:26.000Z | 2020-03-20T03:52:26.000Z | DESCRIPTION = "shows info about jobs"
def autocomplete(shell, line, text, state):
pass
def help(shell):
pass
def print_job(shell, id):
for stager in shell.stagers:
for session in stager.sessions:
for job in session.jobs:
if job.id == int(id):
job.di... | 23.795455 | 96 | 0.575931 |
796697da026dce9f5f372cd8d3ce8a48577d4d6f | 138 | py | Python | Codewars/7kyu/the-office-i-outed/Python/solution1.py | RevansChen/online-judge | ad1b07fee7bd3c49418becccda904e17505f3018 | [
"MIT"
] | 7 | 2017-09-20T16:40:39.000Z | 2021-08-31T18:15:08.000Z | Codewars/7kyu/the-office-i-outed/Python/solution1.py | RevansChen/online-judge | ad1b07fee7bd3c49418becccda904e17505f3018 | [
"MIT"
] | null | null | null | Codewars/7kyu/the-office-i-outed/Python/solution1.py | RevansChen/online-judge | ad1b07fee7bd3c49418becccda904e17505f3018 | [
"MIT"
] | null | null | null | # Python - 3.6.0
outed = lambda meet, boss: 'Get Out Now!' if (sum(meet.values()) + meet[boss]) / len(meet) <= 5 else 'Nice Work Champ!'
| 34.5 | 119 | 0.615942 |
79669b0b6a5e46e2c00bd6cc530f68da6fb29578 | 2,698 | py | Python | PacMan Like/Hero.py | titos-carrasco/Games | ac42b984c1fb6b209281f1aae43ff7987c973160 | [
"MIT"
] | null | null | null | PacMan Like/Hero.py | titos-carrasco/Games | ac42b984c1fb6b209281f1aae43ff7987c973160 | [
"MIT"
] | null | null | null | PacMan Like/Hero.py | titos-carrasco/Games | ac42b984c1fb6b209281f1aae43ff7987c973160 | [
"MIT"
] | null | null | null | #!/usr/bin/env python
# -*- coding: utf-8 -*-
import pygame
from Sprite import Sprite
class Hero( Sprite ):
def __init__( self, x, y, width, height, fname ):
Sprite.__init__( self, x, y, width, height )
bitmap = pygame.image.load( fname ).convert_alpha()
self.images[ self.UP ] = (
... | 44.229508 | 78 | 0.519274 |
79669b6354130a8a4fd56bd532acc5de3a7fa611 | 5,848 | py | Python | env/lib/python3.8/site-packages/ask_sdk_model/interfaces/alexa/presentation/aplt/set_value_command.py | adamash99/alexa-play-pot-of-greed | dc2d18dae55692a4bf1becb72685a5777870c643 | [
"MIT"
] | 90 | 2018-09-19T21:56:42.000Z | 2022-03-30T11:25:21.000Z | ask-sdk-model/ask_sdk_model/interfaces/alexa/presentation/aplt/set_value_command.py | ishitaojha/alexa-apis-for-python | a68f94b7a0e41f819595d6fe56e800403e8a4194 | [
"Apache-2.0"
] | 11 | 2018-09-23T12:16:48.000Z | 2021-06-10T19:49:45.000Z | ask-sdk-model/ask_sdk_model/interfaces/alexa/presentation/aplt/set_value_command.py | ishitaojha/alexa-apis-for-python | a68f94b7a0e41f819595d6fe56e800403e8a4194 | [
"Apache-2.0"
] | 28 | 2018-09-19T22:30:38.000Z | 2022-02-22T22:57:07.000Z | # coding: utf-8
#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "lice... | 38.473684 | 159 | 0.627223 |
79669be3ad13f3bcceb2d6074b906a74d6ee6616 | 495 | py | Python | data/scripts/templates/object/resource_container/shared_resource_container_energy_liquid.py | obi-two/GameServer | 7d37024e2291a97d49522610cd8f1dbe5666afc2 | [
"MIT"
] | 20 | 2015-02-23T15:11:56.000Z | 2022-03-18T20:56:48.000Z | data/scripts/templates/object/resource_container/shared_resource_container_energy_liquid.py | apathyboy/swganh | 665128efe9154611dec4cb5efc61d246dd095984 | [
"MIT"
] | null | null | null | data/scripts/templates/object/resource_container/shared_resource_container_energy_liquid.py | apathyboy/swganh | 665128efe9154611dec4cb5efc61d246dd095984 | [
"MIT"
] | 20 | 2015-04-04T16:35:59.000Z | 2022-03-24T14:54:37.000Z | #### NOTICE: THIS FILE IS AUTOGENERATED
#### MODIFICATIONS MAY BE LOST IF DONE IMPROPERLY
#### PLEASE SEE THE ONLINE DOCUMENTATION FOR EXAMPLES
from swgpy.object import *
def create(kernel):
result = ResourceContainer()
result.template = "object/resource_container/shared_resource_container_energy_liquid.iff"
res... | 29.117647 | 90 | 0.755556 |
79669c042ebbafb5a10a542f347f40a31faf082e | 3,427 | py | Python | tests/nbeats/test_stacks.py | vikua/time-series-experiments | 2f9d3fa842866c39c8c1a9906c8c5d4870a6f7da | [
"MIT"
] | null | null | null | tests/nbeats/test_stacks.py | vikua/time-series-experiments | 2f9d3fa842866c39c8c1a9906c8c5d4870a6f7da | [
"MIT"
] | 4 | 2020-10-11T15:14:48.000Z | 2022-02-10T02:28:07.000Z | tests/nbeats/test_stacks.py | vikua/time-series-experiments | 2f9d3fa842866c39c8c1a9906c8c5d4870a6f7da | [
"MIT"
] | null | null | null | import random
import pytest
import numpy as np
import tensorflow as tf
from tensorflow import keras
from time_series_experiments.nbeats.blocks import BlockTypes
from time_series_experiments.nbeats.stacks import (
DRESSStack,
ParallelStack,
NoResidualStack,
LastForwardStack,
NoResidualLastForwardSt... | 32.028037 | 88 | 0.653633 |
79669c9d13b6fd9192c0fdf15a2a907a699e8c96 | 10,308 | py | Python | contrib/RemoteSensing/nets/unet.py | tianlanshidai/PaddleSeg | f506494b20b93de74b21237f70b76097755da786 | [
"Apache-2.0"
] | 1 | 2022-02-08T02:14:54.000Z | 2022-02-08T02:14:54.000Z | contrib/RemoteSensing/nets/unet.py | tianlanshidai/PaddleSeg | f506494b20b93de74b21237f70b76097755da786 | [
"Apache-2.0"
] | null | null | null | contrib/RemoteSensing/nets/unet.py | tianlanshidai/PaddleSeg | f506494b20b93de74b21237f70b76097755da786 | [
"Apache-2.0"
] | 2 | 2021-07-07T02:23:16.000Z | 2022-02-08T02:14:58.000Z | # coding: utf8
# Copyright (c) 2019 PaddlePaddle Authors. All Rights Reserve.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless requ... | 38.319703 | 89 | 0.56752 |
79669d4cc0d5de226e398dc629f65df77d28d8b2 | 1,171 | py | Python | src/phoenics/ObservationProcessor/__init__.py | taotao720/experiment_planners | 811e331d4a5cff39882ada32d5f068d858000276 | [
"Apache-2.0"
] | 5 | 2019-11-26T02:23:38.000Z | 2020-07-20T15:17:46.000Z | src/phoenics/ObservationProcessor/__init__.py | taotao720/experiment_planners | 811e331d4a5cff39882ada32d5f068d858000276 | [
"Apache-2.0"
] | 4 | 2021-11-11T13:28:08.000Z | 2022-01-17T16:32:58.000Z | src/phoenics/ObservationProcessor/__init__.py | taotao720/experiment_planners | 811e331d4a5cff39882ada32d5f068d858000276 | [
"Apache-2.0"
] | 2 | 2019-11-25T17:46:07.000Z | 2020-06-28T23:20:32.000Z | #!/usr/bin/env python
'''
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements. See the NOTICE file distributed with this
work for additional information regarding copyright ownership. The ASF
licenses this file to you under the Apache License, Version 2.0 (the
"Licens... | 39.033333 | 75 | 0.733561 |
79669e4c6ba783634b940070b42f03f5c89ee631 | 4,028 | py | Python | GeneticAlgorithm_v2.0/individual.py | PrimaryKey/Scripts | 02fd0094876176e983486c55a1d6555fb0b13421 | [
"Apache-2.0"
] | 1 | 2021-06-15T09:23:07.000Z | 2021-06-15T09:23:07.000Z | GeneticAlgorithm_v2.0/individual.py | PrimaryKey/Scripts | 02fd0094876176e983486c55a1d6555fb0b13421 | [
"Apache-2.0"
] | null | null | null | GeneticAlgorithm_v2.0/individual.py | PrimaryKey/Scripts | 02fd0094876176e983486c55a1d6555fb0b13421 | [
"Apache-2.0"
] | null | null | null | # -*- coding: utf-8 -*-
from math import sin,cos,tan,floor
import random
from pandas import Series
import numpy as np
from numpy import array
class Individual():
def __init__(self,genetic):
self.genetic=genetic
self.count=100 #个体数
self.iterNum=200 #染色体进化/迭代次数
self.fitness=0 #个... | 29.40146 | 97 | 0.564052 |
79669e74ee22a095cecdd2229a3a9f2e9c6f29c0 | 1,580 | py | Python | jfscripts/mac_to_eui64.py | Josef-Friedrich/python-scripts | 783d5af27690d832a2992c4c05ab3eb9d6638069 | [
"MIT"
] | 1 | 2021-07-28T02:28:19.000Z | 2021-07-28T02:28:19.000Z | jfscripts/mac_to_eui64.py | Josef-Friedrich/jfscripts | 783d5af27690d832a2992c4c05ab3eb9d6638069 | [
"MIT"
] | null | null | null | jfscripts/mac_to_eui64.py | Josef-Friedrich/jfscripts | 783d5af27690d832a2992c4c05ab3eb9d6638069 | [
"MIT"
] | null | null | null | #! /usr/bin/env python3
from jfscripts import __version__
import argparse
import ipaddress
import re
def mac_to_eui64(mac, prefix=None):
'''
Convert a MAC address to a EUI64 address
or, with prefix provided, a full IPv6 address
'''
# http://tools.ietf.org/html/rfc4291#section-2.5.1
eui64 = re... | 22.253521 | 69 | 0.589241 |
79669ea5eb23ca4997052494d985166e10243eee | 4,381 | py | Python | gameduino2/remote.py | lightcalamar/Asset-Tools-FT81X-v3 | b7b5979e54585583a18b1de7d7be96a592624085 | [
"BSD-3-Clause"
] | null | null | null | gameduino2/remote.py | lightcalamar/Asset-Tools-FT81X-v3 | b7b5979e54585583a18b1de7d7be96a592624085 | [
"BSD-3-Clause"
] | null | null | null | gameduino2/remote.py | lightcalamar/Asset-Tools-FT81X-v3 | b7b5979e54585583a18b1de7d7be96a592624085 | [
"BSD-3-Clause"
] | null | null | null | import array
import StringIO
import zlib
import Image
import struct
import time
import convert
def pad4(s):
while len(s) % 4:
s += chr(0)
return s
import gameduino2.registers as reg
import gameduino2.base
class GD2Exception(Exception):
pass
class GD2(gameduino2.base.GD2):
def __init__(self... | 29.802721 | 115 | 0.533668 |
79669ed71f81047afe86903dababa4688119339c | 207 | py | Python | src/distribution/testapp/setup.py | TutorialForPython/tool-chain | be48e28cd2987aa29dc5498a59c53258827b6dcb | [
"MIT"
] | null | null | null | src/distribution/testapp/setup.py | TutorialForPython/tool-chain | be48e28cd2987aa29dc5498a59c53258827b6dcb | [
"MIT"
] | null | null | null | src/distribution/testapp/setup.py | TutorialForPython/tool-chain | be48e28cd2987aa29dc5498a59c53258827b6dcb | [
"MIT"
] | null | null | null | from setuptools import setup, find_packages
packages = find_packages()
print(packages)
setup(
name = "testapp",
version = "0.0.1",
packages = packages,
data_files=[('', ['__main__.py', ])]
) | 20.7 | 43 | 0.647343 |
7966a0d73bac31e2ac38dc3f9b5b059bd5f38c34 | 75 | py | Python | flask_production/plugins/__init__.py | shashfrankenstien/CherryFlask | b1343c26f41b64f6b343f7a811bdfb09e7e70749 | [
"MIT"
] | null | null | null | flask_production/plugins/__init__.py | shashfrankenstien/CherryFlask | b1343c26f41b64f6b343f7a811bdfb09e7e70749 | [
"MIT"
] | null | null | null | flask_production/plugins/__init__.py | shashfrankenstien/CherryFlask | b1343c26f41b64f6b343f7a811bdfb09e7e70749 | [
"MIT"
] | null | null | null | from .task_monitor import TaskMonitor
from .ctrl_panel import ControlPanel
| 25 | 37 | 0.866667 |
7966a1008865554b8823f3273fd7aacb40a3925e | 2,707 | py | Python | src/Zope2/utilities/tests/test_zconsole.py | rbanffy/Zope | ecf6770219052e7c7f8c9634ddf187a1e6280742 | [
"ZPL-2.1"
] | null | null | null | src/Zope2/utilities/tests/test_zconsole.py | rbanffy/Zope | ecf6770219052e7c7f8c9634ddf187a1e6280742 | [
"ZPL-2.1"
] | null | null | null | src/Zope2/utilities/tests/test_zconsole.py | rbanffy/Zope | ecf6770219052e7c7f8c9634ddf187a1e6280742 | [
"ZPL-2.1"
] | null | null | null | import os
import shutil
import sys
import tempfile
import unittest
from io import StringIO
from App.config import getConfiguration
from App.config import setConfiguration
zope_conf_template = """
%define INSTANCE {}
instancehome $INSTANCE
<zodb_db main>
<filestorage>
path $INSTANCE/Data.fs
</filestorage... | 27.622449 | 75 | 0.6099 |
7966a20110b15f8f0ad7091c11935e9fad8f18b7 | 9,055 | py | Python | sdk/network/azure-mgmt-network/azure/mgmt/network/v2017_06_01/operations/_load_balancer_frontend_ip_configurations_operations.py | vbarbaresi/azure-sdk-for-python | 397ba46c51d001ff89c66b170f5576cf8f49c05f | [
"MIT"
] | 8 | 2021-01-13T23:44:08.000Z | 2021-03-17T10:13:36.000Z | sdk/network/azure-mgmt-network/azure/mgmt/network/v2017_06_01/operations/_load_balancer_frontend_ip_configurations_operations.py | vbarbaresi/azure-sdk-for-python | 397ba46c51d001ff89c66b170f5576cf8f49c05f | [
"MIT"
] | null | null | null | sdk/network/azure-mgmt-network/azure/mgmt/network/v2017_06_01/operations/_load_balancer_frontend_ip_configurations_operations.py | vbarbaresi/azure-sdk-for-python | 397ba46c51d001ff89c66b170f5576cf8f49c05f | [
"MIT"
] | null | null | null | # coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may ... | 48.945946 | 228 | 0.675428 |
7966a2d5f41759122ed965b4f9cdf90f1e573906 | 1,160 | py | Python | edexOsgi/com.raytheon.uf.common.management/pythonPackages/dynamicserialize/dstypes/com/raytheon/uf/common/management/response/diagnostic/ClusterMembersResponse.py | srcarter3/awips2 | 37f31f5e88516b9fd576eaa49d43bfb762e1d174 | [
"Apache-2.0"
] | null | null | null | edexOsgi/com.raytheon.uf.common.management/pythonPackages/dynamicserialize/dstypes/com/raytheon/uf/common/management/response/diagnostic/ClusterMembersResponse.py | srcarter3/awips2 | 37f31f5e88516b9fd576eaa49d43bfb762e1d174 | [
"Apache-2.0"
] | null | null | null | edexOsgi/com.raytheon.uf.common.management/pythonPackages/dynamicserialize/dstypes/com/raytheon/uf/common/management/response/diagnostic/ClusterMembersResponse.py | srcarter3/awips2 | 37f31f5e88516b9fd576eaa49d43bfb762e1d174 | [
"Apache-2.0"
] | 1 | 2021-10-30T00:03:05.000Z | 2021-10-30T00:03:05.000Z | ##
# This software was developed and / or modified by Raytheon Company,
# pursuant to Contract DG133W-05-CQ-1067 with the US Government.
#
# U.S. EXPORT CONTROLLED TECHNICAL DATA
# This software product contains export-restricted data whose
# export/transfer/disclosure is restricted by U.S. law. Dissemination
# to non... | 29 | 69 | 0.649138 |
7966a2ed3ac13f5354d28ae24a4da7133dc757e4 | 10,652 | py | Python | data_steward/analytics/table_metrics/combined_deid_scripts/measurement_integration_success_rate.py | jp3477/curation | 41f98d57c8273d9963ad6d466a237c99b63c74be | [
"MIT"
] | null | null | null | data_steward/analytics/table_metrics/combined_deid_scripts/measurement_integration_success_rate.py | jp3477/curation | 41f98d57c8273d9963ad6d466a237c99b63c74be | [
"MIT"
] | null | null | null | data_steward/analytics/table_metrics/combined_deid_scripts/measurement_integration_success_rate.py | jp3477/curation | 41f98d57c8273d9963ad6d466a237c99b63c74be | [
"MIT"
] | null | null | null | # ---
# jupyter:
# jupytext:
# formats: ipynb,py:light
# text_representation:
# extension: .py
# format_name: light
# format_version: '1.5'
# jupytext_version: 1.3.0
# kernelspec:
# display_name: Python 3
# language: python
# name: python3
# ---
from google.cloud import ... | 27.453608 | 98 | 0.64739 |
7966a3560c9d99d9f85ccfd51168e2cb304cd6ad | 13,539 | py | Python | vo/PWC/correlation.py | zhengsipeng/compass | ed763eb9b6e15c1ddab9b174a00a860167ee9b39 | [
"MIT"
] | 34 | 2022-02-23T10:36:34.000Z | 2022-03-27T08:29:00.000Z | vo/PWC/correlation.py | zhengsipeng/compass | ed763eb9b6e15c1ddab9b174a00a860167ee9b39 | [
"MIT"
] | 1 | 2022-03-06T20:16:01.000Z | 2022-03-22T15:11:11.000Z | vo/PWC/correlation.py | zhengsipeng/compass | ed763eb9b6e15c1ddab9b174a00a860167ee9b39 | [
"MIT"
] | 5 | 2022-03-04T02:41:27.000Z | 2022-03-31T03:48:44.000Z | #!/usr/bin/env python
import torch
import cupy
import re
kernel_Correlation_rearrange = '''
extern "C" __global__ void kernel_Correlation_rearrange(
const int n,
const float* input,
float* output
) {
int intIndex = (blockIdx.x * blockDim.x) + threadIdx.x;
if (intIndex >= n) {
return;
}
int... | 34.103275 | 155 | 0.606766 |
7966a38cc439e45409bed17d5a8b49f429988279 | 7,935 | py | Python | backend/m2c/tests/elf_file.py | ChrisNonyminus/decomp.me | b51e8d586ba95bd20f6b2e5881ecc34459e761bc | [
"MIT"
] | 47 | 2021-11-05T14:20:58.000Z | 2022-03-19T18:56:46.000Z | backend/m2c/tests/elf_file.py | ChrisNonyminus/decomp.me | b51e8d586ba95bd20f6b2e5881ecc34459e761bc | [
"MIT"
] | 131 | 2021-10-20T09:17:16.000Z | 2022-03-31T22:22:54.000Z | backend/m2c/tests/elf_file.py | ChrisNonyminus/decomp.me | b51e8d586ba95bd20f6b2e5881ecc34459e761bc | [
"MIT"
] | 20 | 2021-11-23T18:49:45.000Z | 2022-03-29T06:25:10.000Z | import struct
from dataclasses import dataclass, field
from typing import Any, Dict, List, Optional, Tuple
# Based on the ELF file parser in simonlindholm's asm-differ ("diff.py")
# https://github.com/simonlindholm/asm-differ/blob/4b38c884c1efdc3bfa8b14f13015a69368a8d3a2/diff.py#L1137-L1247
@dataclass(order=True)
c... | 35.58296 | 111 | 0.528544 |
7966a4e892ed1749fd0c3f3df05981fa540feb8b | 315 | py | Python | cherry/envs/state_lambda_wrapper.py | acse-yl27218/cherry | 5b349cae64b282facf5a874164690c06808b1c61 | [
"Apache-2.0"
] | 160 | 2019-09-14T05:33:29.000Z | 2022-03-12T18:58:51.000Z | cherry/envs/state_lambda_wrapper.py | acse-yl27218/cherry | 5b349cae64b282facf5a874164690c06808b1c61 | [
"Apache-2.0"
] | 14 | 2019-12-05T12:14:05.000Z | 2022-02-28T14:52:52.000Z | cherry/envs/state_lambda_wrapper.py | acse-yl27218/cherry | 5b349cae64b282facf5a874164690c06808b1c61 | [
"Apache-2.0"
] | 28 | 2019-09-17T02:25:46.000Z | 2022-03-12T19:53:58.000Z | #!/usr/bin/env python3
from gym import ObservationWrapper
from .base import Wrapper
class StateLambda(Wrapper, ObservationWrapper):
def __init__(self, env, fn):
super(StateLambda, self).__init__(env)
self.fn = fn
def observation(self, observation):
return self.fn(observation)
| 19.6875 | 47 | 0.698413 |
7966a5311b6b8b278261a304b2dcf2c44debd5f0 | 558 | py | Python | website/articles/migrations/0005_auto_20210712_0024.py | NevoleMarek/website-portfolio | 006ff89743a5cd26094e7026748a0adb0c786b57 | [
"MIT"
] | null | null | null | website/articles/migrations/0005_auto_20210712_0024.py | NevoleMarek/website-portfolio | 006ff89743a5cd26094e7026748a0adb0c786b57 | [
"MIT"
] | null | null | null | website/articles/migrations/0005_auto_20210712_0024.py | NevoleMarek/website-portfolio | 006ff89743a5cd26094e7026748a0adb0c786b57 | [
"MIT"
] | null | null | null | # Generated by Django 3.2.5 on 2021-07-11 22:24
from django.db import migrations, models
class Migration(migrations.Migration):
dependencies = [
('articles', '0004_article_description'),
]
operations = [
migrations.AlterField(
model_name='article',
name='created'... | 23.25 | 58 | 0.587814 |
7966a5784bc70be5fa96523b0c927a47c9d86b0b | 14,244 | py | Python | docs/conf.py | iamkuldeepsingh/kedro | 1ccd6d41a9edf5b707ae33e167a625ff3a679bef | [
"Apache-2.0"
] | 1 | 2020-12-01T15:19:30.000Z | 2020-12-01T15:19:30.000Z | docs/conf.py | iamkuldeepsingh/kedro | 1ccd6d41a9edf5b707ae33e167a625ff3a679bef | [
"Apache-2.0"
] | 1 | 2020-02-04T10:17:25.000Z | 2020-02-04T10:17:25.000Z | docs/conf.py | iamkuldeepsingh/kedro | 1ccd6d41a9edf5b707ae33e167a625ff3a679bef | [
"Apache-2.0"
] | 1 | 2020-02-01T09:07:02.000Z | 2020-02-01T09:07:02.000Z | #!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# Kedro documentation build configuration file, created by
# sphinx-quickstart on Mon Dec 18 11:31:24 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# auto... | 31.374449 | 88 | 0.621665 |
7966a5cac75db67e51e25a5cceaf1ee903ebde15 | 1,298 | py | Python | setup.py | gGonz/django-socialnetworks | 3f6c577efafd6ed5eb8b5cb60d9ee6a36920581d | [
"Apache-2.0"
] | 5 | 2015-06-18T03:30:28.000Z | 2017-11-04T21:34:20.000Z | setup.py | gGonz/django-socialnetworks | 3f6c577efafd6ed5eb8b5cb60d9ee6a36920581d | [
"Apache-2.0"
] | 2 | 2015-04-25T00:06:19.000Z | 2015-04-30T22:42:40.000Z | setup.py | gGonz/django-socialnetworks | 3f6c577efafd6ed5eb8b5cb60d9ee6a36920581d | [
"Apache-2.0"
] | 4 | 2015-06-11T18:28:04.000Z | 2016-09-07T15:08:09.000Z | #!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from setuptools import setup, find_packages
from socialnetworks import __author__, __version__
setup(
name='django-socialnetworks',
version=__version__,
description=('Extends Django with “log in” and “share” functionalities '
'for t... | 29.5 | 76 | 0.621726 |
7966a6d9b2e7fd608c0a564055fd0472d2440220 | 7,179 | py | Python | docs/conf.py | wschoenell/astroquery | fe8a5e31035a1e9cdcf2603fb4da9e2fc5000d31 | [
"BSD-3-Clause"
] | 1 | 2015-05-10T00:58:21.000Z | 2015-05-10T00:58:21.000Z | docs/conf.py | wschoenell/astroquery | fe8a5e31035a1e9cdcf2603fb4da9e2fc5000d31 | [
"BSD-3-Clause"
] | null | null | null | docs/conf.py | wschoenell/astroquery | fe8a5e31035a1e9cdcf2603fb4da9e2fc5000d31 | [
"BSD-3-Clause"
] | null | null | null | # -*- coding: utf-8 -*-
# Licensed under a 3-clause BSD style license - see LICENSE.rst
#
# Astropy documentation build configuration file.
#
# This file is execfile()d with the current directory set to its containing dir.
#
# Note that not all possible configuration values are present in this file.
#
# All configurati... | 37.196891 | 87 | 0.692158 |
7966a808da05306c5264ffbc18a8e1deb211069f | 362 | py | Python | micromort/resources/configs/twitter_getter_config.py | mannu1200/micromort | fda09926d71e9f504af39b448aba1221c62316f4 | [
"MIT"
] | null | null | null | micromort/resources/configs/twitter_getter_config.py | mannu1200/micromort | fda09926d71e9f504af39b448aba1221c62316f4 | [
"MIT"
] | null | null | null | micromort/resources/configs/twitter_getter_config.py | mannu1200/micromort | fda09926d71e9f504af39b448aba1221c62316f4 | [
"MIT"
] | null | null | null | #!/usr/bin/env python
twitter_getter_config = {
"key_sets" : [{
"APP_KEY" : "j7R6sWaAzXRTX52tbHvSvX5KO",
"APP_SECRET" : 'jYC9gxztoE6ySbRL1OpYBc9SzNswKlWGCMj89USsiTatsIwHLm',
"OAUTH_TOKEN" : '2694891187-UbGyo15L0QiwTgVRVGScqR3VQ5CoXQzrdnlh8Pc',
"OAUTH_TOKEN_SECRET" : 'pPtvNeMOtECP5... | 32.909091 | 78 | 0.71547 |
7966a80a879dd2d80d2d8de1106ee70686c33f67 | 265 | py | Python | abc/240/A.py | tonko2/AtCoder | 5d617072517881d226d7c8af09cb88684d41af7e | [
"Xnet",
"X11",
"CECILL-B"
] | 2 | 2022-01-22T07:56:58.000Z | 2022-01-24T00:29:37.000Z | abc/240/A.py | tonko2/AtCoder | 5d617072517881d226d7c8af09cb88684d41af7e | [
"Xnet",
"X11",
"CECILL-B"
] | null | null | null | abc/240/A.py | tonko2/AtCoder | 5d617072517881d226d7c8af09cb88684d41af7e | [
"Xnet",
"X11",
"CECILL-B"
] | null | null | null | import sys
sys.setrecursionlimit(10 ** 6)
stdin = sys.stdin
ni = lambda: int(ns())
na = lambda: list(map(int, stdin.readline().split()))
ns = lambda: stdin.readline().strip()
a, b = na()
if a + 1 == b or a == 1 and b == 10:
print("Yes")
else:
print("No") | 18.928571 | 53 | 0.596226 |
7966a8ba468b348a17bae1939c8dfe91a55c495a | 7,977 | py | Python | 5/intcode.py | elp2/advent_of_code_2019 | af3ce232fb6597dbc80e96bdfd5a6248f07aa3c6 | [
"Apache-2.0"
] | 1 | 2021-12-02T15:19:36.000Z | 2021-12-02T15:19:36.000Z | 5/intcode.py | elp2/advent_of_code_2019 | af3ce232fb6597dbc80e96bdfd5a6248f07aa3c6 | [
"Apache-2.0"
] | null | null | null | 5/intcode.py | elp2/advent_of_code_2019 | af3ce232fb6597dbc80e96bdfd5a6248f07aa3c6 | [
"Apache-2.0"
] | null | null | null | import unittest
class IntCodeComputer:
def __init__(self, memory, inputs=[]):
self.pc = 0
self.memory = memory
self.halted = False
self.debugging = True
print('Memory: len=%d' % (len(self.memory)))
self.inputs = inputs
self.inputs.reverse()
self.outpu... | 33.800847 | 172 | 0.585057 |
7966aa84c52745fb99c299836b36c742fe8404bd | 403 | py | Python | 12gensim/05.tensorflow.py | KEVINYZY/python-tutorial | ae43536908eb8af56c34865f52a6e8644edc4fa3 | [
"Apache-2.0"
] | 2 | 2021-01-04T10:44:44.000Z | 2022-02-13T07:53:41.000Z | 12gensim/05.tensorflow.py | zm79287/python-tutorial | d0f7348e1da4ff954e3add66e1aae55d599283ee | [
"Apache-2.0"
] | null | null | null | 12gensim/05.tensorflow.py | zm79287/python-tutorial | d0f7348e1da4ff954e3add66e1aae55d599283ee | [
"Apache-2.0"
] | 2 | 2020-11-23T08:58:51.000Z | 2022-02-13T07:53:42.000Z | # -*- coding: utf-8 -*-
"""
@description:
@author:XuMing
"""
from __future__ import print_function # 兼容python3的print写法
from __future__ import unicode_literals # 兼容python3的编码处理
import tensorflow as tf
x = tf.constant(1, tf.float32)
y = tf.nn.relu(x)
dy = tf.gradients(y, x)
ddy = tf.gradients(dy, x)
with tf.Session(... | 21.210526 | 58 | 0.689826 |
7966aacea58252ca5cf2d95f9695e78e72682a71 | 88,894 | py | Python | fireant/tests/slicer/widgets/test_highcharts.py | vladaspasic/fireant | 2dbae6a97a927ef62fdcd5f37fcb51a7d6d55334 | [
"Apache-2.0"
] | null | null | null | fireant/tests/slicer/widgets/test_highcharts.py | vladaspasic/fireant | 2dbae6a97a927ef62fdcd5f37fcb51a7d6d55334 | [
"Apache-2.0"
] | null | null | null | fireant/tests/slicer/widgets/test_highcharts.py | vladaspasic/fireant | 2dbae6a97a927ef62fdcd5f37fcb51a7d6d55334 | [
"Apache-2.0"
] | null | null | null | import copy
from unittest import (
TestCase,
skip,
)
from fireant import CumSum
from fireant.slicer.widgets.highcharts import (
DEFAULT_COLORS,
HighCharts,
)
from fireant.tests.slicer.mocks import (
ElectionOverElection,
cat_dim_df,
cat_dim_totals_df,
cat_uni_dim_df,
cont_dim_df,
... | 38.666377 | 107 | 0.392062 |
7966aaf2247e4a48025717ec892883936b5730a5 | 228 | py | Python | pycaishen/ioengines/storage.py | spyamine/pycaishen3 | 33f756fd0ad2bd05eb0d21fd4e7e8573e317a6a9 | [
"Apache-2.0"
] | 1 | 2019-06-17T10:17:30.000Z | 2019-06-17T10:17:30.000Z | pycaishen/ioengines/storage.py | spyamine/pycaishen3 | 33f756fd0ad2bd05eb0d21fd4e7e8573e317a6a9 | [
"Apache-2.0"
] | null | null | null | pycaishen/ioengines/storage.py | spyamine/pycaishen3 | 33f756fd0ad2bd05eb0d21fd4e7e8573e317a6a9 | [
"Apache-2.0"
] | null | null | null | # from pycaishen.pycaishenstorage import PycaishenStorage
# if __name__ == '__main__':
#
# storage = PycaishenStorage("arctic")
# l = "azertyuiopmlkjhgfdsqwxcvbn"
# l = list(l)
# for s in l:
# storage.
#
| 22.8 | 57 | 0.635965 |
7966abb0e1941e4509c5bfb7b431d1b20aefa5e7 | 13,180 | py | Python | accelbyte_py_sdk/api/basic/models/user_profile_private_update.py | AccelByte/accelbyte-python-sdk | dcd311fad111c59da828278975340fb92e0f26f7 | [
"MIT"
] | null | null | null | accelbyte_py_sdk/api/basic/models/user_profile_private_update.py | AccelByte/accelbyte-python-sdk | dcd311fad111c59da828278975340fb92e0f26f7 | [
"MIT"
] | 1 | 2021-10-13T03:46:58.000Z | 2021-10-13T03:46:58.000Z | accelbyte_py_sdk/api/basic/models/user_profile_private_update.py | AccelByte/accelbyte-python-sdk | dcd311fad111c59da828278975340fb92e0f26f7 | [
"MIT"
] | null | null | null | # Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!
# template file: justice_py_sdk_codegen/__main__.py
# justice-basic-service (1.36.3)
# pylint: disable=d... | 40.182927 | 193 | 0.594992 |
7966abe3a53334d0f9b3597442cebfe5b7cd2be1 | 4,416 | py | Python | personal_site/forum/forms.py | gorel/personal-site | be84afd8f970dfade9ee03ea87cce1dcb8fb5042 | [
"MIT"
] | null | null | null | personal_site/forum/forms.py | gorel/personal-site | be84afd8f970dfade9ee03ea87cce1dcb8fb5042 | [
"MIT"
] | null | null | null | personal_site/forum/forms.py | gorel/personal-site | be84afd8f970dfade9ee03ea87cce1dcb8fb5042 | [
"MIT"
] | null | null | null | import datetime
import flask
import flask_login
import flask_wtf
import wtforms
from personal_site import constants, db
from personal_site.forum import models
class NewPostForm(flask_wtf.FlaskForm):
title = wtforms.StringField(
"Title",
validators=[
wtforms.validators.DataRequired(),... | 31.542857 | 85 | 0.624321 |
7966ac6ee10c05d1287e9b394c3cf7089412a6be | 2,190 | py | Python | amelia/vectorize_and_predict.py | zygmuntz/kaggle-happiness | ea5f181673d11c8acce115fc68301b5ea4f3a383 | [
"MIT"
] | 40 | 2015-01-24T03:08:37.000Z | 2021-02-16T01:45:49.000Z | amelia/vectorize_and_predict.py | vasulakkaraju/kaggle-happiness | ea5f181673d11c8acce115fc68301b5ea4f3a383 | [
"MIT"
] | null | null | null | amelia/vectorize_and_predict.py | vasulakkaraju/kaggle-happiness | ea5f181673d11c8acce115fc68301b5ea4f3a383 | [
"MIT"
] | 31 | 2015-01-06T13:06:39.000Z | 2020-01-15T08:10:07.000Z | "vectorize imputed set, predict"
"can take params from command line - used by predict_many.py"
import sys
import numpy as np
import pandas as pd
import sqlite3
from math import sqrt
from sklearn.feature_extraction import DictVectorizer as DV
from sklearn.svm import SVC
###
points_in_test = 1980
data_dir = '/path/to... | 22.346939 | 126 | 0.7 |
7966ac869cd62cd0354ccdb39d07c32b6fc63d8e | 84,791 | py | Python | great_expectations/expectations/self_check_util.py | vanderGoes/great_expectations | 9790cd992a8a4de672c640e89ddd7278a0ca0889 | [
"Apache-2.0"
] | null | null | null | great_expectations/expectations/self_check_util.py | vanderGoes/great_expectations | 9790cd992a8a4de672c640e89ddd7278a0ca0889 | [
"Apache-2.0"
] | null | null | null | great_expectations/expectations/self_check_util.py | vanderGoes/great_expectations | 9790cd992a8a4de672c640e89ddd7278a0ca0889 | [
"Apache-2.0"
] | null | null | null | # TODO: This util module contains methods required to execute expectations examples as tests.
# The methods were pretty hastily copied from test_utils and conftest. It is very possible
# that some are not even needed. A cleanup pass is required.
import copy
import locale
import os
import random
import string
import t... | 42.780525 | 155 | 0.569129 |
7966acf297fa3b07f05dd478c5e02bcdcbcd0b40 | 23,578 | py | Python | src/pymodaq/daq_viewer/utility_classes.py | jerlfan/PyMoDAQ | d77636fbe686685a257b99c36281194da196851f | [
"CECILL-B"
] | null | null | null | src/pymodaq/daq_viewer/utility_classes.py | jerlfan/PyMoDAQ | d77636fbe686685a257b99c36281194da196851f | [
"CECILL-B"
] | null | null | null | src/pymodaq/daq_viewer/utility_classes.py | jerlfan/PyMoDAQ | d77636fbe686685a257b99c36281194da196851f | [
"CECILL-B"
] | null | null | null | import os
from PyQt5 import QtWidgets
from PyQt5.QtCore import QObject, pyqtSlot, pyqtSignal
from pymodaq.daq_utils.parameter import ioxml
from pymodaq.daq_utils.parameter.utils import get_param_path, get_param_from_name, iter_children
from pyqtgraph.parametertree import Parameter
from easydict import EasyDict as edic... | 41.730973 | 248 | 0.521503 |
7966ad6ac49fa3534b5059e39176b7431e75176c | 2,161 | py | Python | utz/escape.py | ryan-williams/jupyter-rc | 362d9d758498de317976006ce7dfc65e2bce2c57 | [
"MIT"
] | null | null | null | utz/escape.py | ryan-williams/jupyter-rc | 362d9d758498de317976006ce7dfc65e2bce2c57 | [
"MIT"
] | 2 | 2020-11-18T15:36:35.000Z | 2021-06-25T18:21:32.000Z | utz/escape.py | runsascoded/utz | 362d9d758498de317976006ce7dfc65e2bce2c57 | [
"MIT"
] | 1 | 2020-06-10T23:14:00.000Z | 2020-06-10T23:14:00.000Z |
import re
from re import escape, finditer
def split(s, ch, max=0):
'''Split `s` on character `ch`, unescaping backslash-escaped instances of `ch` (and unescaping double-backslashes to
single backslashes)
If `max` is passed, `max` groups will be extracted, and a final (max+1)th group will be appended to ... | 31.318841 | 120 | 0.544655 |
7966af320ecfc58afe852512c713dec17a265ad7 | 2,130 | py | Python | dolphinscheduler-python/pydolphinscheduler/src/pydolphinscheduler/examples/task_switch_example.py | guoshupei/dolphinscheduler | 48d526f275f941d2068985b22747fd017a4d48e0 | [
"Apache-2.0"
] | 2 | 2021-11-16T13:01:44.000Z | 2022-03-11T03:10:08.000Z | dolphinscheduler-python/pydolphinscheduler/src/pydolphinscheduler/examples/task_switch_example.py | zonghequ1/dolphinscheduler | 922283ee9c91268608c61219aeead51f9fb48187 | [
"Apache-2.0"
] | 1 | 2020-03-05T08:07:52.000Z | 2020-03-05T08:07:52.000Z | dolphinscheduler-python/pydolphinscheduler/src/pydolphinscheduler/examples/task_switch_example.py | zonghequ1/dolphinscheduler | 922283ee9c91268608c61219aeead51f9fb48187 | [
"Apache-2.0"
] | 3 | 2022-03-14T07:16:22.000Z | 2022-03-21T03:04:55.000Z | # Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements. See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership. The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not u... | 40.961538 | 109 | 0.729108 |
7966affe3608d5e4481a3ff87b3b842f1bdd5d39 | 2,257 | py | Python | bin/validate-storage-schemas.py | jblaine/carbon | d3903c5e1c9fb4c401161d380a432f58cfda9d20 | [
"Apache-2.0"
] | 8 | 2015-04-09T19:08:32.000Z | 2019-04-16T09:04:41.000Z | bin/validate-storage-schemas.py | jblaine/carbon | d3903c5e1c9fb4c401161d380a432f58cfda9d20 | [
"Apache-2.0"
] | 1 | 2017-03-23T17:52:21.000Z | 2017-03-23T17:52:21.000Z | bin/validate-storage-schemas.py | jblaine/carbon | d3903c5e1c9fb4c401161d380a432f58cfda9d20 | [
"Apache-2.0"
] | 14 | 2015-03-30T07:05:21.000Z | 2021-02-24T15:18:18.000Z | #!/usr/bin/env python
"""Copyright 2009 Chris Davis
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in ... | 31.788732 | 101 | 0.716881 |
7966b057f009d381d95aa163e806b091f435dd3c | 1,526 | py | Python | db_tools/import_goods_data.py | LauZyHou/MxShop_Back | 4e1be205ec88960b26262a51440fd91d952db37d | [
"MIT"
] | 1 | 2021-09-17T02:52:23.000Z | 2021-09-17T02:52:23.000Z | db_tools/import_goods_data.py | LauZyHou/MxShop_Back | 4e1be205ec88960b26262a51440fd91d952db37d | [
"MIT"
] | null | null | null | db_tools/import_goods_data.py | LauZyHou/MxShop_Back | 4e1be205ec88960b26262a51440fd91d952db37d | [
"MIT"
] | null | null | null | # encoding: utf-8
__author__ = 'mtianyan'
__date__ = '2018/2/14 0014 03:31'
import sys
import os
pwd = os.path.dirname(os.path.realpath(__file__))
sys.path.append(pwd + "../")
os.environ.setdefault("DJANGO_SETTINGS_MODULE", "MxShop_Back.settings")
import django
django.setup()
from goods.models import Goods, GoodsCa... | 34.681818 | 99 | 0.711664 |
7966b1a2c0f3abf54a792d4c3b35e64e8ca095b1 | 4,923 | py | Python | tensorflow/contrib/testing/python/framework/fake_summary_writer.py | atfkaka/tensorflow | 5657d0dee8d87f4594b3e5902ed3e3ca8d6dfc0a | [
"Apache-2.0"
] | 101 | 2016-12-03T11:40:52.000Z | 2017-12-23T02:02:03.000Z | tensorflow/contrib/testing/python/framework/fake_summary_writer.py | atfkaka/tensorflow | 5657d0dee8d87f4594b3e5902ed3e3ca8d6dfc0a | [
"Apache-2.0"
] | 9 | 2016-12-14T03:27:46.000Z | 2017-09-13T02:29:07.000Z | tensorflow/contrib/testing/python/framework/fake_summary_writer.py | atfkaka/tensorflow | 5657d0dee8d87f4594b3e5902ed3e3ca8d6dfc0a | [
"Apache-2.0"
] | 47 | 2016-12-04T12:37:24.000Z | 2018-01-14T18:13:07.000Z | # Copyright 2015 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applica... | 38.76378 | 80 | 0.730043 |
7966b2cacb6b95a330cba0ab2f67d7a646c7a0a3 | 795 | py | Python | Resources/books/deep_learning_time_series_forecasting/code/chapter_16/05_plots_of_daily_power_consumption.py | gdepalma93/bright-athlete-academy | 54ba0cc6633637c1bd6d90120153e04b981244bf | [
"MIT"
] | null | null | null | Resources/books/deep_learning_time_series_forecasting/code/chapter_16/05_plots_of_daily_power_consumption.py | gdepalma93/bright-athlete-academy | 54ba0cc6633637c1bd6d90120153e04b981244bf | [
"MIT"
] | null | null | null | Resources/books/deep_learning_time_series_forecasting/code/chapter_16/05_plots_of_daily_power_consumption.py | gdepalma93/bright-athlete-academy | 54ba0cc6633637c1bd6d90120153e04b981244bf | [
"MIT"
] | null | null | null | # daily line plots for power usage dataset
from pandas import read_csv
from matplotlib import pyplot
# load the new file
dataset = read_csv('household_power_consumption.csv', header=0, infer_datetime_format=True, parse_dates=['datetime'], index_col=['datetime'])
# plot active power for each year
days = [x for x in rang... | 34.565217 | 141 | 0.727044 |
7966b2e5781b8ef0491cb752dfc4081ee1b11d02 | 6,143 | py | Python | tests/tasks/test_task_service.py | DaeunYim/pgtoolsservice | b7e548718d797883027b2caee2d4722810b33c0f | [
"MIT"
] | 33 | 2019-05-27T13:04:35.000Z | 2022-03-17T13:33:05.000Z | tests/tasks/test_task_service.py | DaeunYim/pgtoolsservice | b7e548718d797883027b2caee2d4722810b33c0f | [
"MIT"
] | 31 | 2019-06-10T01:55:47.000Z | 2022-03-09T07:27:49.000Z | tests/tasks/test_task_service.py | DaeunYim/pgtoolsservice | b7e548718d797883027b2caee2d4722810b33c0f | [
"MIT"
] | 25 | 2019-05-13T18:39:24.000Z | 2021-11-16T03:07:33.000Z | # --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------... | 49.540323 | 156 | 0.712193 |
7966b31b4352d9a556972a3b44fe4c0fdbc71ff3 | 436 | py | Python | base/migrations/0018_alter_palabra_cantidadderepasoshastaelproximonivel.py | francofgp/Syndeo | 888a1001f2cbb2ff8b7247e84a2899dcbd08af80 | [
"MIT"
] | 3 | 2022-01-04T17:38:04.000Z | 2022-01-05T12:45:22.000Z | base/migrations/0018_alter_palabra_cantidadderepasoshastaelproximonivel.py | francofgp/Syndeo | 888a1001f2cbb2ff8b7247e84a2899dcbd08af80 | [
"MIT"
] | null | null | null | base/migrations/0018_alter_palabra_cantidadderepasoshastaelproximonivel.py | francofgp/Syndeo | 888a1001f2cbb2ff8b7247e84a2899dcbd08af80 | [
"MIT"
] | null | null | null | # Generated by Django 3.2.2 on 2021-07-26 22:50
from django.db import migrations, models
class Migration(migrations.Migration):
dependencies = [
('base', '0017_palabra_esfrase'),
]
operations = [
migrations.AlterField(
model_name='palabra',
name='cantidadDeRepaso... | 22.947368 | 75 | 0.630734 |
7966b549e6c5d1d55a027c9a18274dcf7fd0d2d5 | 5,283 | py | Python | local_sidercars/local_control_management/lcp/src/schema/config.py | guard-project/guard-platform | 8de5a5381a913d7ccb96962b6ccf900a740e4ce7 | [
"MIT"
] | 2 | 2022-02-28T21:08:25.000Z | 2022-02-28T21:08:27.000Z | local_sidercars/local_control_management/lcp/src/schema/config.py | guard-project/guard-platform | 8de5a5381a913d7ccb96962b6ccf900a740e4ce7 | [
"MIT"
] | null | null | null | local_sidercars/local_control_management/lcp/src/schema/config.py | guard-project/guard-platform | 8de5a5381a913d7ccb96962b6ccf900a740e4ce7 | [
"MIT"
] | null | null | null | from marshmallow import validate
from marshmallow.fields import Boolean, Constant, DateTime as Date_Time, Float, Integer, List, Nested, Raw, Str
from schema.base import Base_Schema
from utils.datetime import FORMAT
_all__ = [
'Config_Request_Schema',
'Config_Action_Response_Schema',
'Config_Parameter_Respo... | 42.604839 | 111 | 0.657581 |
7966b6844b51962036500d25f6169a2551239ac7 | 12,632 | py | Python | hTools2.roboFontExt/lib/hTools2/modules/color.py | gferreira/hTools2_extension | 9e5150082a0a39847c1078aac3dc38d914a44f83 | [
"BSD-3-Clause"
] | 1 | 2015-02-10T14:47:39.000Z | 2015-02-10T14:47:39.000Z | hTools2.roboFontExt/lib/hTools2/modules/color.py | gferreira/hTools2_extension | 9e5150082a0a39847c1078aac3dc38d914a44f83 | [
"BSD-3-Clause"
] | 2 | 2017-08-08T21:02:17.000Z | 2019-12-18T15:55:48.000Z | hTools2.roboFontExt/lib/hTools2/modules/color.py | gferreira/hTools2_extension | 9e5150082a0a39847c1078aac3dc38d914a44f83 | [
"BSD-3-Clause"
] | 3 | 2015-08-17T04:09:05.000Z | 2021-08-09T20:22:04.000Z | # [h] hTools2.modules.color
"""Simple tools for working with colors."""
# import
import random
from hTools2.modules.sysutils import _ctx
from hTools2.extras.colorsys import *
#-----------
# functions
#-----------
def random_color(alpha=1.0):
"""Return a random color."""
# FontLab
if _ctx == 'FontLab':
... | 33.775401 | 341 | 0.54069 |
7966b6c00fde48428718518aa5e32f722c6ab745 | 712 | py | Python | server/genanki/models/basic.py | Secretmud/Notion-to-Anki | e16c9d790ad241f3e0fd0084235376547fdddfed | [
"MIT"
] | null | null | null | server/genanki/models/basic.py | Secretmud/Notion-to-Anki | e16c9d790ad241f3e0fd0084235376547fdddfed | [
"MIT"
] | null | null | null | server/genanki/models/basic.py | Secretmud/Notion-to-Anki | e16c9d790ad241f3e0fd0084235376547fdddfed | [
"MIT"
] | null | null | null | from genanki import Model
DEFAULT_BASIC_FRONT = '<span class="front-text-pre">{{Front}}</span>'
DEFAULT_BASIC_BACK = '<span class="front-text-post">{{Front}}</span>' '<hr id="answer">' '<span class="back-text">{{Back}}</span>'
def basic_model(id, name, css, qfmt, afmt):
if qfmt is None:
qfmt = DEFAULT_BAS... | 27.384615 | 130 | 0.484551 |
7966b74d28b294e681aa6e7dbfd0884d030298f4 | 7,636 | py | Python | pynetdicom/apps/echoscp/echoscp.py | vsaase/pynetdicom | a2d21efeec932e09c178b9794794d94c556bf5a9 | [
"MIT"
] | 1 | 2020-08-03T02:11:27.000Z | 2020-08-03T02:11:27.000Z | pynetdicom/apps/echoscp/echoscp.py | vsaase/pynetdicom | a2d21efeec932e09c178b9794794d94c556bf5a9 | [
"MIT"
] | null | null | null | pynetdicom/apps/echoscp/echoscp.py | vsaase/pynetdicom | a2d21efeec932e09c178b9794794d94c556bf5a9 | [
"MIT"
] | null | null | null | #!/usr/bin/env python
"""
An echoscp application.
Used for verifying basic DICOM connectivity and as such has a focus on
providing useful debugging and logging information.
"""
import argparse
import logging
from logging.config import fileConfig
import os
import socket
import sys
from pydicom.uid import (
Expli... | 35.516279 | 85 | 0.607517 |
7966b7e544bcfc2038ee1e96d75005984dbf597b | 16,214 | py | Python | primes/quadratic_sieve.py | tpott/pub_musings | 7d617a1fbed7c6f47fb5236fcf5cb9baffef4bce | [
"MIT"
] | null | null | null | primes/quadratic_sieve.py | tpott/pub_musings | 7d617a1fbed7c6f47fb5236fcf5cb9baffef4bce | [
"MIT"
] | 1 | 2021-11-28T20:55:29.000Z | 2021-11-28T20:55:29.000Z | primes/quadratic_sieve.py | tpott/pub_musings | 7d617a1fbed7c6f47fb5236fcf5cb9baffef4bce | [
"MIT"
] | null | null | null | # quadratic_sieve.py
# Trevor Pottinger
# Fri Dec 6 22:57:30 PST 2019
from __future__ import division
from __future__ import print_function
import argparse
import math
import multiprocessing
import sys
if sys.version_info >= (3, 3):
from typing import Callable, Dict, List, Optional, Tuple, TypeVar
greater_... | 31.854617 | 143 | 0.571111 |
7966b8dc60ceefeaa267f8b9f0f4181ee00abd8a | 3,448 | py | Python | gradient/commands/hyperparameters.py | vishalbelsare/gradient-cli | c0e06252925cad3ad73d47ded1100f6b0cb0989a | [
"0BSD"
] | 52 | 2019-06-10T04:20:00.000Z | 2021-12-06T01:13:26.000Z | gradient/commands/hyperparameters.py | vishalbelsare/gradient-cli | c0e06252925cad3ad73d47ded1100f6b0cb0989a | [
"0BSD"
] | 125 | 2019-06-05T16:34:19.000Z | 2022-03-30T18:46:06.000Z | gradient/commands/hyperparameters.py | vishalbelsare/gradient-cli | c0e06252925cad3ad73d47ded1100f6b0cb0989a | [
"0BSD"
] | 11 | 2019-07-16T06:48:55.000Z | 2021-12-15T12:41:51.000Z | import abc
import six
from gradient import api_sdk, exceptions
from gradient.api_sdk import sdk_exceptions
from gradient.cli_constants import CLI_PS_CLIENT_NAME
from gradient.commands.common import BaseCommand, ListCommandMixin, DetailsCommandMixin
from gradient.commands.experiments import BaseCreateExperimentCommand... | 35.916667 | 103 | 0.707947 |
7966b8e4d03bafbfddd453c6c8ee07544806a0d2 | 2,066 | py | Python | cds_ils/importer/XMLRecordToJson.py | CERNDocumentServer/cds-ils | a153fff9be9a23b4c9d44568cc16481d888ffd13 | [
"MIT"
] | 6 | 2020-09-18T00:13:38.000Z | 2021-11-14T17:12:19.000Z | cds_ils/importer/XMLRecordToJson.py | CERNDocumentServer/cds-ils | a153fff9be9a23b4c9d44568cc16481d888ffd13 | [
"MIT"
] | 321 | 2020-08-28T15:42:25.000Z | 2022-03-14T15:11:50.000Z | cds_ils/importer/XMLRecordToJson.py | CERNDocumentServer/cds-ils | a153fff9be9a23b4c9d44568cc16481d888ffd13 | [
"MIT"
] | 4 | 2020-08-31T08:55:47.000Z | 2022-01-14T11:30:23.000Z | # -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2015-2018 CERN.
#
# cds-ils is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.
"""CDS Importer Records loader."""
import datetime
from cds_dojson.marc21.utils imp... | 28.694444 | 73 | 0.637948 |
7966b9a78c346d288126f8b286557100f4ebc82b | 6,945 | py | Python | dbReports/iondb/bin/fix_missingSystemPlanTemplates.py | sequencer2014/TS | 465804570349d46b47c1bdf131bdafea5c582dee | [
"Apache-2.0"
] | null | null | null | dbReports/iondb/bin/fix_missingSystemPlanTemplates.py | sequencer2014/TS | 465804570349d46b47c1bdf131bdafea5c582dee | [
"Apache-2.0"
] | null | null | null | dbReports/iondb/bin/fix_missingSystemPlanTemplates.py | sequencer2014/TS | 465804570349d46b47c1bdf131bdafea5c582dee | [
"Apache-2.0"
] | null | null | null | #!/usr/bin/env python
# Copyright (C) 2013 Ion Torrent Systems, Inc. All Rights Reserved
from djangoinit import *
from django.db import transaction
import sys
import os
from iondb.rundb import models
import datetime
import uuid
import random
import string
from traceback import format_exc
# 20130228 change log:
# a... | 35.798969 | 158 | 0.682361 |
7966ba22473e54fb130ce1c7a03632227a157a02 | 1,916 | py | Python | bot/venv/lib/python3.7/site-packages/pyglet/media/codecs/ffmpeg_lib/__init__.py | manaccac/sc2_bot | 3aa8b3711378b71fd0a44662cdd7148846e39530 | [
"MIT"
] | 2 | 2021-05-16T07:39:38.000Z | 2021-05-30T22:04:42.000Z | bot/venv/lib/python3.7/site-packages/pyglet/media/codecs/ffmpeg_lib/__init__.py | manaccac/sc2_bot | 3aa8b3711378b71fd0a44662cdd7148846e39530 | [
"MIT"
] | 5 | 2021-01-21T09:46:12.000Z | 2022-02-14T13:54:44.000Z | bot/venv/lib/python3.7/site-packages/pyglet/media/codecs/ffmpeg_lib/__init__.py | manaccac/sc2_bot | 3aa8b3711378b71fd0a44662cdd7148846e39530 | [
"MIT"
] | 2 | 2021-11-02T11:01:53.000Z | 2022-02-14T10:11:21.000Z | # ----------------------------------------------------------------------------
# pyglet
# Copyright (c) 2006-2008 Alex Holkner
# Copyright (c) 2008-2020 pyglet contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the follo... | 46.731707 | 78 | 0.70929 |
7966ba99482693ad9869d45ef5e108e0c395b602 | 302,287 | py | Python | src/recogni/system_rdl/SystemRDLParser.py | recogni/open-register-design-tool | 8871630261e0b54291d5885f27fb7ae5f2438cc7 | [
"Apache-2.0"
] | 1 | 2019-12-06T19:11:50.000Z | 2019-12-06T19:11:50.000Z | src/recogni/system_rdl/SystemRDLParser.py | recogni/open-register-design-tool | 8871630261e0b54291d5885f27fb7ae5f2438cc7 | [
"Apache-2.0"
] | null | null | null | src/recogni/system_rdl/SystemRDLParser.py | recogni/open-register-design-tool | 8871630261e0b54291d5885f27fb7ae5f2438cc7 | [
"Apache-2.0"
] | null | null | null | # Generated from ../ordt/parse/grammars/SystemRDL.g4 by ANTLR 4.5.3
# encoding: utf-8
from antlr4 import *
from io import StringIO
def serializedATN():
with StringIO() as buf:
buf.write("\3\u0430\ud6d1\u8206\uad2d\u4417\uaef1\u8d80\uaadd\3\u012f")
buf.write("\u040d\4\2\t\2\4\3\t\3\4\4\t\4\4\5\t\5\... | 42.491847 | 4,779 | 0.594266 |
7966ba9c249457275f55b582fab171ad0f233b8d | 597 | py | Python | lidar_coh/scripts/script_template.py | nhamilto/lidar_coh | 16b46a59f7c560dd93eff8eb5978c8e56ce96c95 | [
"Apache-2.0"
] | null | null | null | lidar_coh/scripts/script_template.py | nhamilto/lidar_coh | 16b46a59f7c560dd93eff8eb5978c8e56ce96c95 | [
"Apache-2.0"
] | null | null | null | lidar_coh/scripts/script_template.py | nhamilto/lidar_coh | 16b46a59f7c560dd93eff8eb5978c8e56ce96c95 | [
"Apache-2.0"
] | null | null | null | #!/usr/bin/env python
"""
DESCRIPTION
TODO This describes how to use this script. This docstring
will be printed by the script if there is an error or
if the user requests help (-h or --help).
AUTHOR
Nicholas Hamilton
nicholas.hamilton@nrel.gov
Date: ${BUILDDATE}
"""
import sys, os, traceback,... | 16.583333 | 62 | 0.666667 |
7966bacc031c31883fec53a40e5b83ccd321587c | 7,021 | py | Python | notebooks/boost_and_layouts/test_layouts.py | compgeolab/eql-gradient-boosted | 759a0c6f34e92d83551b14c8dfaeae2a8be1e949 | [
"BSD-3-Clause"
] | 17 | 2021-02-25T18:03:14.000Z | 2022-03-28T22:47:37.000Z | notebooks/boost_and_layouts/test_layouts.py | compgeolab/eql-gradient-boosted | 759a0c6f34e92d83551b14c8dfaeae2a8be1e949 | [
"BSD-3-Clause"
] | 24 | 2021-02-25T15:21:40.000Z | 2021-08-25T10:29:33.000Z | notebooks/boost_and_layouts/test_layouts.py | compgeolab/eql-gradient-boosted | 759a0c6f34e92d83551b14c8dfaeae2a8be1e949 | [
"BSD-3-Clause"
] | 4 | 2021-07-27T15:55:05.000Z | 2021-09-17T07:26:42.000Z | """
Test functions for layouts constructors
"""
import pytest
import numpy as np
import numpy.testing as npt
import verde as vd
from .layouts import (
constant_depth,
relative_depth,
variable_depth,
source_below_data,
block_averaged_sources,
grid_sources,
)
@pytest.fixture
def coordinates():
... | 28.425101 | 86 | 0.64535 |
7966bad3affcffee19a9076923e8abf9ac08db69 | 18,851 | py | Python | cartridge/shop/views.py | kenbolton/cartridge | e3402d37c3b35830d3b94bac678dad0d27a06698 | [
"BSD-2-Clause"
] | 372 | 2015-01-01T05:48:43.000Z | 2022-03-26T18:19:45.000Z | cartridge/shop/views.py | kenbolton/cartridge | e3402d37c3b35830d3b94bac678dad0d27a06698 | [
"BSD-2-Clause"
] | 235 | 2015-01-05T02:17:22.000Z | 2022-03-25T16:09:02.000Z | cartridge/shop/views.py | kenbolton/cartridge | e3402d37c3b35830d3b94bac678dad0d27a06698 | [
"BSD-2-Clause"
] | 239 | 2015-01-06T12:06:47.000Z | 2022-03-08T07:58:56.000Z | from __future__ import unicode_literals
from future.builtins import int, str
from json import dumps
from django.contrib.auth.decorators import login_required
from django.contrib.messages import info
from django.core.urlresolvers import reverse
from django.db.models import Sum
from django.http import Http404, HttpResp... | 42.843182 | 79 | 0.630364 |
7966bb9c41cdba3c0f29ef80a0936af34c29e8d4 | 643 | py | Python | src/manage.py | thatlarrypearson/telemetry-django-server | d7708996704cb5f758ed3cc5c6e97a2efa81687b | [
"MIT"
] | null | null | null | src/manage.py | thatlarrypearson/telemetry-django-server | d7708996704cb5f758ed3cc5c6e97a2efa81687b | [
"MIT"
] | 3 | 2020-01-22T05:13:43.000Z | 2020-04-28T18:36:18.000Z | src/manage.py | thatlarrypearson/telemetry-django-server | d7708996704cb5f758ed3cc5c6e97a2efa81687b | [
"MIT"
] | null | null | null | #!/usr/bin/env python
"""Django's command-line utility for administrative tasks."""
import os
import sys
def main():
os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'telemetry_django_server.settings')
try:
from django.core.management import execute_from_command_line
except ImportError as exc:
... | 29.227273 | 87 | 0.690513 |
7966bba2485a238d84e0fad0d0c23810eae3bb87 | 11,028 | py | Python | python/ray/tests/test_multi_node.py | mickelliu/ray | 9cec28d439aca3458d9207379447251aa7b97e4f | [
"Apache-2.0"
] | 2 | 2022-03-25T04:15:10.000Z | 2022-03-25T04:15:15.000Z | python/ray/tests/test_multi_node.py | mickelliu/ray | 9cec28d439aca3458d9207379447251aa7b97e4f | [
"Apache-2.0"
] | 227 | 2021-10-01T08:00:01.000Z | 2021-12-28T16:47:26.000Z | python/ray/tests/test_multi_node.py | mickelliu/ray | 9cec28d439aca3458d9207379447251aa7b97e4f | [
"Apache-2.0"
] | null | null | null | import os
import pytest
import psutil
import sys
import time
import ray
from ray import ray_constants
from ray._private.test_utils import (
RayTestTimeoutException, run_string_as_driver,
run_string_as_driver_nonblocking, init_error_pubsub, get_error_message,
object_memory_usage, wait_for_condition)
@pyte... | 27.432836 | 79 | 0.677639 |
7966bc1641dd55e82c0b2dfedf7810493c866f6c | 367 | py | Python | panlex_scraper/pipelines.py | raphaelmerx/panlex_scraper | e22608ce798b1e77d303b13147c075ff688241c0 | [
"MIT"
] | 2 | 2022-02-05T19:47:55.000Z | 2022-02-20T00:27:47.000Z | panlex_scraper/pipelines.py | raphaelmerx/panlex_scraper | e22608ce798b1e77d303b13147c075ff688241c0 | [
"MIT"
] | null | null | null | panlex_scraper/pipelines.py | raphaelmerx/panlex_scraper | e22608ce798b1e77d303b13147c075ff688241c0 | [
"MIT"
] | null | null | null | # Define your item pipelines here
#
# Don't forget to add your pipeline to the ITEM_PIPELINES setting
# See: https://docs.scrapy.org/en/latest/topics/item-pipeline.html
# useful for handling different item types with a single interface
from itemadapter import ItemAdapter
class PanlexScraperPipeline:
def process... | 26.214286 | 66 | 0.771117 |
7966bc8b04fd2aea6f7948af12c0d4604a9847c8 | 68 | py | Python | tests/test_config/__init__.py | Lulaba/Twitter-Monitor | 050edd53900fe543adc12cb086ef6778e6c487e3 | [
"MIT"
] | null | null | null | tests/test_config/__init__.py | Lulaba/Twitter-Monitor | 050edd53900fe543adc12cb086ef6778e6c487e3 | [
"MIT"
] | 1 | 2021-06-01T23:21:07.000Z | 2021-06-01T23:21:07.000Z | tests/test_webhook/__init__.py | Lulaba/Twitter-Monitor | 050edd53900fe543adc12cb086ef6778e6c487e3 | [
"MIT"
] | null | null | null | import unittest
if __name__ == "__main__":
unittest.main()
| 13.6 | 27 | 0.647059 |
7966bc920872a37726d675afed445a52ad71c953 | 4,586 | py | Python | FAPESP/coleta_amostral/webScraping_SophiA.py | tainacan/data_science | a36c977f3aba6ce8bc45b1433ead673fd3c2674f | [
"CC0-1.0"
] | 2 | 2021-04-12T15:05:18.000Z | 2021-08-19T01:57:38.000Z | FAPESP/coleta_amostral/webScraping_SophiA.py | tainacan/data_science | a36c977f3aba6ce8bc45b1433ead673fd3c2674f | [
"CC0-1.0"
] | null | null | null | FAPESP/coleta_amostral/webScraping_SophiA.py | tainacan/data_science | a36c977f3aba6ce8bc45b1433ead673fd3c2674f | [
"CC0-1.0"
] | null | null | null | from selenium import webdriver
import pandas as pd
import random
import time
#Configura o webdriver como Firefox
#Link para donwload do geckodriver do Firefox - https://github.com/mozilla/geckodriver/releases
#Necessita do geckodriver salvo em uma pasta identificada nas variáveis de ambiente PATH.
#(Sugiro sal... | 43.67619 | 145 | 0.611644 |
7966bc98eee40d449609f5311431cba50e0906aa | 731 | py | Python | abc/abc250/c/main.py | tonko2/AtCoder | 5d617072517881d226d7c8af09cb88684d41af7e | [
"Xnet",
"X11",
"CECILL-B"
] | 2 | 2022-01-22T07:56:58.000Z | 2022-01-24T00:29:37.000Z | abc/abc250/c/main.py | tonko2/AtCoder | 5d617072517881d226d7c8af09cb88684d41af7e | [
"Xnet",
"X11",
"CECILL-B"
] | null | null | null | abc/abc250/c/main.py | tonko2/AtCoder | 5d617072517881d226d7c8af09cb88684d41af7e | [
"Xnet",
"X11",
"CECILL-B"
] | null | null | null | import sys
import math
from collections import defaultdict, deque, Counter
sys.setrecursionlimit(10 ** 6)
stdin = sys.stdin
INF = float('inf')
ni = lambda: int(ns())
na = lambda: list(map(int, stdin.readline().split()))
ns = lambda: stdin.readline().strip()
N, Q = na()
A = []
d = defaultdict(int) # d[num] = index
d... | 20.305556 | 53 | 0.567715 |
7966bd962280e2cf1850eee3da4973e7c28d1f6c | 125 | py | Python | mongoshapes/fields/multipoint/pep484/__init__.py | phuntimes/mongoshapes | f461c67343c32c6b97af8d67a269b4de492d1d71 | [
"MIT"
] | 1 | 2020-11-26T05:58:23.000Z | 2020-11-26T05:58:23.000Z | mongoshapes/fields/multipoint/pep484/__init__.py | Sean-McVeigh/mongoshapes | f461c67343c32c6b97af8d67a269b4de492d1d71 | [
"MIT"
] | null | null | null | mongoshapes/fields/multipoint/pep484/__init__.py | Sean-McVeigh/mongoshapes | f461c67343c32c6b97af8d67a269b4de492d1d71 | [
"MIT"
] | null | null | null | #!/usr/bin/env python
# -*- coding: utf-8 -*-
from .dict import MultiPointDict
from .type import MultiPoint, MultiPointType
| 20.833333 | 44 | 0.728 |
7966befeb944d534606c4e6c94b7f52c17f88e85 | 3,367 | py | Python | paradise/hooks.py | pfrydlewicz/paradise | bdd2597d259ab7313a140d82de4afce5961b0cb6 | [
"MIT"
] | null | null | null | paradise/hooks.py | pfrydlewicz/paradise | bdd2597d259ab7313a140d82de4afce5961b0cb6 | [
"MIT"
] | null | null | null | paradise/hooks.py | pfrydlewicz/paradise | bdd2597d259ab7313a140d82de4afce5961b0cb6 | [
"MIT"
] | null | null | null | # -*- coding: utf-8 -*-
from __future__ import unicode_literals
from . import __version__ as app_version
app_name = "paradise"
app_title = "Paradise"
app_publisher = "FCON"
app_description = "General custom enhancements for ERPNext."
app_icon = "octicon octicon-file-directory"
app_color = "grey"
app_email = "it@berlia... | 24.757353 | 94 | 0.659638 |
7966bf487319325d8978fb0de489f666ad22d5ce | 6,105 | py | Python | createMultiplexGraph.py | renoust/ER-STF | 1716d7d1abe4eb5a80c1a3ec2cde1683b858a993 | [
"X11",
"Unlicense",
"MIT"
] | 1 | 2021-04-07T02:21:10.000Z | 2021-04-07T02:21:10.000Z | createMultiplexGraph.py | renoust/ER-STF | 1716d7d1abe4eb5a80c1a3ec2cde1683b858a993 | [
"X11",
"Unlicense",
"MIT"
] | null | null | null | createMultiplexGraph.py | renoust/ER-STF | 1716d7d1abe4eb5a80c1a3ec2cde1683b858a993 | [
"X11",
"Unlicense",
"MIT"
] | null | null | null | # Powered by Python 2.7
# To cancel the modifications performed by the script
# on the current graph, click on the undo button.
# Some useful keyboards shortcuts :
# * Ctrl + D : comment selected lines.
# * Ctrl + Shift + D : uncomment selected lines.
# * Ctrl + I : indent selected lines.
# * Ctrl + Shift +... | 44.562044 | 306 | 0.750041 |
7966c12088344db6c9b1a0f5728f1a50a1c25fab | 872 | py | Python | src/django_postcode_lookup/backends/base.py | VdeJong/django-postcode-lookup | 8292c01f67005f8ae9ab262e2ff40ff306b729a6 | [
"MIT"
] | 8 | 2016-12-12T13:59:56.000Z | 2018-04-26T08:32:31.000Z | src/django_postcode_lookup/backends/base.py | VdeJong/django-postcode-lookup | 8292c01f67005f8ae9ab262e2ff40ff306b729a6 | [
"MIT"
] | 1 | 2016-12-12T14:01:02.000Z | 2016-12-12T14:01:02.000Z | src/django_postcode_lookup/backends/base.py | LabD/django-postcode-lookup | 7e2696795c6b7848e5f5e18799e1c06560c5f89e | [
"MIT"
] | 3 | 2018-10-23T08:38:10.000Z | 2022-01-25T22:06:55.000Z | import attr
from django.core.cache import cache
@attr.s
class PostcodeLookupResult(object):
postcode = attr.ib()
number = attr.ib()
street = attr.ib()
city = attr.ib()
def json(self):
return attr.asdict(self)
class PostcodeLookupException(IOError):
pass
class _none(object):
pa... | 21.268293 | 65 | 0.635321 |
7966c2cea4e40df4b4a4c7dae9f50a1bccc5b696 | 4,962 | py | Python | locations/spiders/interior_health.py | mfjackson/alltheplaces | 37c90b4041c80a574e6e4c2f886883e97df4b636 | [
"MIT"
] | null | null | null | locations/spiders/interior_health.py | mfjackson/alltheplaces | 37c90b4041c80a574e6e4c2f886883e97df4b636 | [
"MIT"
] | null | null | null | locations/spiders/interior_health.py | mfjackson/alltheplaces | 37c90b4041c80a574e6e4c2f886883e97df4b636 | [
"MIT"
] | null | null | null | # -*- coding: utf-8 -*-
import re
import scrapy
from locations.items import GeojsonPointItem
class InteriorHealthSpider(scrapy.Spider):
name = "interior_health"
item_attributes = {"brand": "Interior Health"}
allowed_domains = ["www.interiorhealth.ca"]
start_urls = [
"https://www.interiorheal... | 39.070866 | 143 | 0.56973 |
7966c3e6ecd622eb59f2a7143aeea0a4bb431b40 | 5,870 | py | Python | demo/settings/__init__.py | devkral/oscar-web-payments | 0c5f5c780e503aab5eaa56541b4d9bf976f7e833 | [
"BSD-2-Clause"
] | 1 | 2018-05-29T18:32:59.000Z | 2018-05-29T18:32:59.000Z | demo/settings/__init__.py | devkral/oscar-web-payments | 0c5f5c780e503aab5eaa56541b4d9bf976f7e833 | [
"BSD-2-Clause"
] | 1 | 2018-05-28T08:28:19.000Z | 2018-05-28T08:28:19.000Z | demo/settings/__init__.py | devkral/oscar-web-payments | 0c5f5c780e503aab5eaa56541b4d9bf976f7e833 | [
"BSD-2-Clause"
] | null | null | null | """
Django settings for django_dummy project.
Generated by 'django-admin startproject' using Django 2.0.2.
For more information on this file, see
https://docs.djangoproject.com/en/2.0/topics/settings/
For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.0/ref/settings/
"""
import ... | 30.894737 | 162 | 0.701193 |
7966c3ed9724fc66f6ed96d5a9eadf1042a72f00 | 3,416 | py | Python | train_shrec.py | ID56/Multimodal-Fusion-CRNN | 1775ec0cb9d0878c2635860c291b343130296797 | [
"MIT"
] | null | null | null | train_shrec.py | ID56/Multimodal-Fusion-CRNN | 1775ec0cb9d0878c2635860c291b343130296797 | [
"MIT"
] | null | null | null | train_shrec.py | ID56/Multimodal-Fusion-CRNN | 1775ec0cb9d0878c2635860c291b343130296797 | [
"MIT"
] | null | null | null | from argparse import ArgumentParser
from config_parser import get_config
from utils.loss import LabelSmoothingLoss
from utils.opt import get_optimizer
from utils.scheduler import WarmUpLR, get_scheduler
from utils.trainer import train
from utils.load_SHREC import get_loaders
from utils.misc import seed_everything, cou... | 31.054545 | 134 | 0.613583 |
7966c48568de505f1f9a0993e1ef2fc47e97f16e | 3,305 | py | Python | tests/Tree_test.py | cgat-developers/cgat-apps | 4de381418e80cfd085b17fc8a3048a48f55e57cf | [
"BSD-2-Clause",
"MIT"
] | 19 | 2018-09-07T11:32:49.000Z | 2021-08-24T01:39:37.000Z | tests/Tree_test.py | cgat-developers/cgat-apps | 4de381418e80cfd085b17fc8a3048a48f55e57cf | [
"BSD-2-Clause",
"MIT"
] | 55 | 2018-04-05T15:26:41.000Z | 2022-03-17T09:27:43.000Z | tests/Tree_test.py | cgat-developers/cgat-apps | 4de381418e80cfd085b17fc8a3048a48f55e57cf | [
"BSD-2-Clause",
"MIT"
] | 12 | 2018-02-11T20:07:03.000Z | 2021-04-07T04:50:12.000Z | """unit testing module for the Tree.py class."""
from cgat.Tree import Tree
import unittest
class MidPointRootingCheck(unittest.TestCase):
trees = [
"(A:1,((B:1,C:1):1,D:1):1,(E:1,F:1):1);",
"((A:1,(B:1,C:1):1):0.5,((D:1,E:1):1,F:1):0.5);",
"(A:1,B:1);",
"((A:1,B:1):1,C:5);",
... | 38.882353 | 145 | 0.494705 |
7966c53d6d765d35c1e1128db2041d5cb155b03e | 296 | py | Python | Math/2739_구구단/2739_구구단.py | 7dudtj/BOJ_myCode | 37d105590a7963e2232102b3098fea3c3504b96f | [
"MIT"
] | 1 | 2022-03-30T15:50:47.000Z | 2022-03-30T15:50:47.000Z | Math/2739_구구단/2739_구구단.py | 7dudtj/BOJ_myCode | 37d105590a7963e2232102b3098fea3c3504b96f | [
"MIT"
] | null | null | null | Math/2739_구구단/2739_구구단.py | 7dudtj/BOJ_myCode | 37d105590a7963e2232102b3098fea3c3504b96f | [
"MIT"
] | 1 | 2021-07-20T07:11:06.000Z | 2021-07-20T07:11:06.000Z | N = int(input())
print(''+str(N)+' * 1 =', N*1)
print(''+str(N)+' * 2 =', N*2)
print(''+str(N)+' * 3 =', N*3)
print(''+str(N)+' * 4 =', N*4)
print(''+str(N)+' * 5 =', N*5)
print(''+str(N)+' * 6 =', N*6)
print(''+str(N)+' * 7 =', N*7)
print(''+str(N)+' * 8 =', N*8)
print(''+str(N)+' * 9 =', N*9)
| 26.909091 | 30 | 0.39527 |
7966c5f301797649d54f0ea0b4079324f0d06c0f | 4,346 | py | Python | tests/core/contracts/test_contract_constructor_encoding.py | bhardwajRahul/web3.py | efecadcdea64f9481fcace558a8ea103462e2923 | [
"MIT"
] | 3 | 2022-03-19T08:14:29.000Z | 2022-03-31T12:05:19.000Z | tests/core/contracts/test_contract_constructor_encoding.py | bhardwajRahul/web3.py | efecadcdea64f9481fcace558a8ea103462e2923 | [
"MIT"
] | 1 | 2022-02-17T20:28:58.000Z | 2022-02-17T20:28:58.000Z | tests/core/contracts/test_contract_constructor_encoding.py | bhardwajRahul/web3.py | efecadcdea64f9481fcace558a8ea103462e2923 | [
"MIT"
] | 1 | 2022-03-20T11:54:03.000Z | 2022-03-20T11:54:03.000Z | import pytest
from eth_utils import (
encode_hex,
remove_0x_prefix,
)
def test_contract_constructor_abi_encoding_with_no_constructor_fn(MathContract, MATH_CODE):
deploy_data = MathContract._encode_constructor_data()
assert deploy_data == MATH_CODE
def test_contract_constructor_abi_encoding_with_con... | 36.521008 | 175 | 0.71399 |
7966c6690a7065a565d2910e9d9ac76ddc5ed104 | 3,871 | py | Python | fuzzing/tools/launcher.py | pmarkowsky/rules_fuzzing | b2b3efdcd70d319c6e0e9b687baff3b54e5a5711 | [
"Apache-2.0"
] | 47 | 2020-11-28T10:26:14.000Z | 2022-03-30T22:10:03.000Z | fuzzing/tools/launcher.py | pmarkowsky/rules_fuzzing | b2b3efdcd70d319c6e0e9b687baff3b54e5a5711 | [
"Apache-2.0"
] | 66 | 2020-11-25T14:32:00.000Z | 2022-03-22T23:48:32.000Z | fuzzing/tools/launcher.py | pmarkowsky/rules_fuzzing | b2b3efdcd70d319c6e0e9b687baff3b54e5a5711 | [
"Apache-2.0"
] | 12 | 2020-11-19T21:08:06.000Z | 2022-03-26T14:00:10.000Z | # Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, s... | 35.190909 | 117 | 0.735986 |
7966c7ae20a005f18da3812283268ec084324da8 | 858 | py | Python | Parameters.py | bineet-coderep/Uncertain-Linear-System | 911ff9d66ab97b156e5b51b3583d6b6a584870ac | [
"AFL-1.1"
] | 1 | 2020-11-20T07:38:40.000Z | 2020-11-20T07:38:40.000Z | Parameters.py | bineet-coderep/Uncertain-Linear-System | 911ff9d66ab97b156e5b51b3583d6b6a584870ac | [
"AFL-1.1"
] | null | null | null | Parameters.py | bineet-coderep/Uncertain-Linear-System | 911ff9d66ab97b156e5b51b3583d6b6a584870ac | [
"AFL-1.1"
] | null | null | null | # All the Parameters go here.
'''
Parameters required for the code
'''
import os,sys
'''
Please add the following line in ~/.bashrc
export ULS_ROOT_DIR = <YOUR PROJECT ROOT>
'''
PROJECT_ROOT = os.environ['ULS_ROOT_DIR']
sys.path.append(PROJECT_ROOT)
LIB_PATH=PROJECT_ROOT+'/'+'lib/'
SRC_PATH=PROJECT_ROOT+'/'+'src/'
... | 15.6 | 68 | 0.7669 |
7966c7c7d8c74e294d29ff7672693921c96a1968 | 2,144 | py | Python | neutron/plugins/bigswitch/db/porttracker_db.py | SnabbCo/neutron | a657c06d10f2171149c6b1863df36522bdc11cd7 | [
"Apache-2.0"
] | 1 | 2016-04-19T08:20:19.000Z | 2016-04-19T08:20:19.000Z | neutron/plugins/bigswitch/db/porttracker_db.py | SnabbCo/neutron | a657c06d10f2171149c6b1863df36522bdc11cd7 | [
"Apache-2.0"
] | null | null | null | neutron/plugins/bigswitch/db/porttracker_db.py | SnabbCo/neutron | a657c06d10f2171149c6b1863df36522bdc11cd7 | [
"Apache-2.0"
] | null | null | null | # vim: tabstop=4 shiftwidth=4 softtabstop=4
#
# Copyright 2013, Big Switch Networks
# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
# http://www.apac... | 39.703704 | 78 | 0.708489 |
7966c7e757d83d9d058f1480000346c348193ff9 | 9,718 | py | Python | src/pygeoprocessing/symbolic.py | richpsharp/pygeoprocessing | 51afe79ae402c1dec3beb3805ce6d6be2e4fc0d5 | [
"Apache-2.0"
] | null | null | null | src/pygeoprocessing/symbolic.py | richpsharp/pygeoprocessing | 51afe79ae402c1dec3beb3805ce6d6be2e4fc0d5 | [
"Apache-2.0"
] | null | null | null | src/pygeoprocessing/symbolic.py | richpsharp/pygeoprocessing | 51afe79ae402c1dec3beb3805ce6d6be2e4fc0d5 | [
"Apache-2.0"
] | null | null | null | # coding=UTF-8
"""Module to hold symbolic PyGeoprocessing utilities."""
import ast
import logging
from . import geoprocessing
from .geoprocessing import DEFAULT_GTIFF_CREATION_TUPLE_OPTIONS
from osgeo import gdal
import numpy
LOGGER = logging.getLogger(__name__)
def evaluate_raster_calculator_expressio... | 42.622807 | 81 | 0.634801 |
7966c8d42594af7851b63407f19f53b8cd39ef79 | 31,535 | py | Python | py3status/modules/weather_owm.py | oaken-source/py3status | e8ea159c74f19ddaaa799fc19c3e517105706190 | [
"BSD-3-Clause"
] | null | null | null | py3status/modules/weather_owm.py | oaken-source/py3status | e8ea159c74f19ddaaa799fc19c3e517105706190 | [
"BSD-3-Clause"
] | null | null | null | py3status/modules/weather_owm.py | oaken-source/py3status | e8ea159c74f19ddaaa799fc19c3e517105706190 | [
"BSD-3-Clause"
] | null | null | null | r"""
Display ultimately customizable weather.
This module allows you to specify an icon for nearly every weather scenario
imaginable. The default configuration options lump many of the icons into
a few groups, and due to the limitations of UTF-8, this is really as expressive
as it gets.
This module uses OpenWeatherMa... | 35.552424 | 88 | 0.578849 |
7966c957580aadccb98232963351ddb5a4431757 | 249 | py | Python | examples/plnt/__init__.py | joostdevries/werkzeug | 8f19cc210a68667155e37e6d3d37204f7afc8c38 | [
"BSD-3-Clause"
] | 2 | 2015-12-11T15:27:22.000Z | 2016-05-08T13:32:38.000Z | examples/plnt/__init__.py | Chitrank-Dixit/werkzeug | 60670cb98db1934b7aa7df454cbe4508c467f403 | [
"BSD-3-Clause"
] | null | null | null | examples/plnt/__init__.py | Chitrank-Dixit/werkzeug | 60670cb98db1934b7aa7df454cbe4508c467f403 | [
"BSD-3-Clause"
] | 2 | 2020-07-23T21:55:21.000Z | 2021-01-14T12:27:19.000Z | # -*- coding: utf-8 -*-
"""
plnt
~~~~
Noun. plnt (plant) -- a planet application that sounds like a herb.
:copyright: (c) 2009 by the Werkzeug Team, see AUTHORS for more details.
:license: BSD.
"""
from plnt.webapp import Plnt
| 20.75 | 76 | 0.614458 |
7966c9981fe0397e4648186347dee2a443817e00 | 405 | py | Python | RecommendMovie/asgi.py | wkd-woo/RecommendMovie | ae5507f6466c417e48ff4769a7968082c014da11 | [
"MIT"
] | 2 | 2021-05-05T08:36:37.000Z | 2021-05-09T13:01:32.000Z | RecommendMovie/asgi.py | wkd-woo/RecommendMovie | ae5507f6466c417e48ff4769a7968082c014da11 | [
"MIT"
] | null | null | null | RecommendMovie/asgi.py | wkd-woo/RecommendMovie | ae5507f6466c417e48ff4769a7968082c014da11 | [
"MIT"
] | null | null | null | """
ASGI config for RecommendMovie project.
It exposes the ASGI callable as a module-level variable named ``application``.
For more information on this file, see
https://docs.djangoproject.com/en/3.2/howto/deployment/asgi/
"""
import os
from django.core.asgi import get_asgi_application
os.environ.setdefault('DJANG... | 23.823529 | 78 | 0.792593 |
7966ca814f7406347dfa946f41827f1b3990761d | 1,463 | py | Python | PreprocessData/all_class_files/BusinessEvent.py | wkid-neu/Schema | 4854720a15894dd814691a55e03329ecbbb6f558 | [
"MIT"
] | 3 | 2021-11-06T12:29:05.000Z | 2022-03-22T12:48:55.000Z | PreprocessData/all_class_files/BusinessEvent.py | DylanNEU/Schema | 4854720a15894dd814691a55e03329ecbbb6f558 | [
"MIT"
] | null | null | null | PreprocessData/all_class_files/BusinessEvent.py | DylanNEU/Schema | 4854720a15894dd814691a55e03329ecbbb6f558 | [
"MIT"
] | 1 | 2021-11-06T12:29:12.000Z | 2021-11-06T12:29:12.000Z | from PreprocessData.all_class_files.Event import Event
import global_data
class BusinessEvent(Event):
def __init__(self, additionalType=None, alternateName=None, description=None, disambiguatingDescription=None, identifier=None, image=None, mainEntityOfPage=None, name=None, potentialAction=None, sameAs=None,... | 182.875 | 781 | 0.82365 |
7966caa75b3dc6ff041ae9fb46df9823477ff852 | 5,827 | py | Python | sdk/python/pulumi_azure_native/sql/get_server_key.py | sebtelko/pulumi-azure-native | 711ec021b5c73da05611c56c8a35adb0ce3244e4 | [
"Apache-2.0"
] | null | null | null | sdk/python/pulumi_azure_native/sql/get_server_key.py | sebtelko/pulumi-azure-native | 711ec021b5c73da05611c56c8a35adb0ce3244e4 | [
"Apache-2.0"
] | null | null | null | sdk/python/pulumi_azure_native/sql/get_server_key.py | sebtelko/pulumi-azure-native | 711ec021b5c73da05611c56c8a35adb0ce3244e4 | [
"Apache-2.0"
] | null | null | null | # coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
__a... | 33.488506 | 171 | 0.631886 |
7966caafd70219d09093d5440fc7f9e2b7aaf0bd | 6,368 | py | Python | Exploration Strategy/distancemin.py | salamenthe/STA-Robot-autonome | fb55cb0de0a23c05d049ae7d3859f2b6cdbb9b54 | [
"MIT"
] | null | null | null | Exploration Strategy/distancemin.py | salamenthe/STA-Robot-autonome | fb55cb0de0a23c05d049ae7d3859f2b6cdbb9b54 | [
"MIT"
] | 1 | 2021-11-12T09:48:09.000Z | 2021-11-12T09:48:09.000Z | Exploration Strategy/distancemin.py | salamenthe/STA-Robot-autonome | fb55cb0de0a23c05d049ae7d3859f2b6cdbb9b54 | [
"MIT"
] | null | null | null | # -*- coding: utf-8 -*-
"""
Created on Mon Nov 8 14:48:20 2021
@author: utilisateur
"""
import numpy as np
import heapq
import matplotlib.pyplot as plt
from PIL import Image
# Trouver la zone inexplorée la plus proche du robot
M = np.array([[0,0,1,1],
[0,1,0.5,1],
[0,0,1,1],
[1,... | 27.5671 | 100 | 0.482569 |
7966cb3ce87c80f6793bed977f87287c7a116901 | 7,286 | py | Python | chaos_balls.py | QuantumZain/chaos-balls | bc9738da6901b5d8755aeade26a93f8f51806f90 | [
"MIT"
] | null | null | null | chaos_balls.py | QuantumZain/chaos-balls | bc9738da6901b5d8755aeade26a93f8f51806f90 | [
"MIT"
] | null | null | null | chaos_balls.py | QuantumZain/chaos-balls | bc9738da6901b5d8755aeade26a93f8f51806f90 | [
"MIT"
] | null | null | null | from pygame.gfxdraw import circle
from reflection import arrow, yellow
from drawing import aacirlce
import pygame
import os
import time as t
from math import acos, atan2, sin, cos, sqrt, pi
import math
from test import dot, simul
# Game presets
start_time = t.time()
fps = 120
width, height = 590, 470
#... | 33.269406 | 165 | 0.560253 |
7966cbb8a119b72c315bf48ffc6b69ba88fbd162 | 154 | py | Python | pyquick/__init__.py | munisisazade/pyquick | b2850745b0f45bc1ac777847efe6bad95754f7b8 | [
"MIT"
] | 1 | 2018-06-19T11:10:56.000Z | 2018-06-19T11:10:56.000Z | pyquick/__init__.py | munisisazade/pyquick | b2850745b0f45bc1ac777847efe6bad95754f7b8 | [
"MIT"
] | null | null | null | pyquick/__init__.py | munisisazade/pyquick | b2850745b0f45bc1ac777847efe6bad95754f7b8 | [
"MIT"
] | null | null | null | from __future__ import unicode_literals
from pyquick.utils.version import get_version
VERSION = (0, 0, 1, "beta", 0)
__version__ = get_version(VERSION) | 22 | 45 | 0.779221 |
7966cc4456deaa22e3c958aecef2215dd045cf3b | 96 | py | Python | rubiks_cube/__init__.py | IguanaAzul/RubiksCube | 11ad845bda16deae9fa24e3d556ce883c06b673c | [
"MIT"
] | 5 | 2020-11-18T18:23:41.000Z | 2021-01-31T17:44:51.000Z | rubiks_cube/__init__.py | IguanaAzul/RubiksCube | 11ad845bda16deae9fa24e3d556ce883c06b673c | [
"MIT"
] | null | null | null | rubiks_cube/__init__.py | IguanaAzul/RubiksCube | 11ad845bda16deae9fa24e3d556ce883c06b673c | [
"MIT"
] | null | null | null | from .rubiks_cube import Cube
from .face_cube import FaceCube
from .cubie_cube import CubieCube
| 24 | 33 | 0.84375 |
7966ce0f3bc6c2556521c8ab62583e1f7c916da3 | 670 | py | Python | OpenGLWrapper_JE/venv/Lib/site-packages/OpenGL/raw/GLES2/ANGLE/texture_usage.py | JE-Chen/je_old_repo | a8b2f1ac2eec25758bd15b71c64b59b27e0bcda5 | [
"MIT"
] | null | null | null | OpenGLWrapper_JE/venv/Lib/site-packages/OpenGL/raw/GLES2/ANGLE/texture_usage.py | JE-Chen/je_old_repo | a8b2f1ac2eec25758bd15b71c64b59b27e0bcda5 | [
"MIT"
] | null | null | null | OpenGLWrapper_JE/venv/Lib/site-packages/OpenGL/raw/GLES2/ANGLE/texture_usage.py | JE-Chen/je_old_repo | a8b2f1ac2eec25758bd15b71c64b59b27e0bcda5 | [
"MIT"
] | null | null | null | '''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C
... | 39.411765 | 123 | 0.801493 |
7966cf22b34b2d85884c327f6acddca63e6c65cf | 23,470 | py | Python | Tests/ML/utils/test_io_util.py | MaxCodeXTC/InnerEye-DeepLearning | 12b496093097ef48d5ac8880985c04918d7f76fe | [
"MIT"
] | 1 | 2020-09-23T07:26:37.000Z | 2020-09-23T07:26:37.000Z | Tests/ML/utils/test_io_util.py | MaxCodeXTC/InnerEye-DeepLearning | 12b496093097ef48d5ac8880985c04918d7f76fe | [
"MIT"
] | null | null | null | Tests/ML/utils/test_io_util.py | MaxCodeXTC/InnerEye-DeepLearning | 12b496093097ef48d5ac8880985c04918d7f76fe | [
"MIT"
] | null | null | null | # ------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License (MIT). See LICENSE in the repo root for license information.
# -------------------------------------------------------------------... | 44.116541 | 112 | 0.668556 |
7966cf6a7f6e746c134cf9f63712d0ce18c2f389 | 437 | py | Python | reboot.py | bfg100k/HuaweiB525Router | dd2c6b2954b1e48f571e6024c2c5fb29e90ef0b1 | [
"MIT"
] | 64 | 2019-02-05T23:31:57.000Z | 2022-02-13T22:59:31.000Z | reboot.py | bfg100k/HuaweiB525Router | dd2c6b2954b1e48f571e6024c2c5fb29e90ef0b1 | [
"MIT"
] | 14 | 2019-07-13T22:43:21.000Z | 2021-01-04T22:46:20.000Z | reboot.py | bfg100k/HuaweiB525Router | dd2c6b2954b1e48f571e6024c2c5fb29e90ef0b1 | [
"MIT"
] | 20 | 2019-05-09T12:48:16.000Z | 2022-01-12T10:55:29.000Z | import huawei_lte.router as lte
import huawei_lte.xmlobjects as xmlobjects
from huawei_lte.errors import RouterError
import datetime
import time
with open("/huaweiB525/reboot.log", mode='a') as file:
file.write('%s\n' %datetime.datetime.now())
router = lte.B525Router('192.168.8.1')
router.login(username='admin', ... | 24.277778 | 54 | 0.778032 |
7966d0c5c4edc4444f51401ba311f4b49ab8ef38 | 10,707 | py | Python | appengine/findit/crash/crash_pipeline.py | mithro/chromium-infra | d27ac0b230bedae4bc968515b02927cf9e17c2b7 | [
"BSD-3-Clause"
] | null | null | null | appengine/findit/crash/crash_pipeline.py | mithro/chromium-infra | d27ac0b230bedae4bc968515b02927cf9e17c2b7 | [
"BSD-3-Clause"
] | null | null | null | appengine/findit/crash/crash_pipeline.py | mithro/chromium-infra | d27ac0b230bedae4bc968515b02927cf9e17c2b7 | [
"BSD-3-Clause"
] | null | null | null | # Copyright 2016 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
import copy
import json
import logging
from crash import monitoring
from common import appengine_util
from common import pubsub_util
from common.pipeline_w... | 44.799163 | 79 | 0.732044 |
7966d20f8b3002148e3abbf095ce65e5723ec494 | 55 | py | Python | storage/team16/Models/avl-tree.py | strickergt128/tytus | 93216dd9481ea0775da1d2967dc27be66872537f | [
"MIT"
] | null | null | null | storage/team16/Models/avl-tree.py | strickergt128/tytus | 93216dd9481ea0775da1d2967dc27be66872537f | [
"MIT"
] | null | null | null | storage/team16/Models/avl-tree.py | strickergt128/tytus | 93216dd9481ea0775da1d2967dc27be66872537f | [
"MIT"
] | null | null | null | from Models.node import Node
class AVLTree:
pass
| 9.166667 | 28 | 0.727273 |
7966d22e7e871f2fa30065f12f18fb09fafb78bc | 506 | py | Python | speed_of_light_in_nanosecond_with_vars.py | jjtoledo/Treinamento-Data-Science | 5117975109695b1de06ae43b416972e66a4b7773 | [
"MIT"
] | null | null | null | speed_of_light_in_nanosecond_with_vars.py | jjtoledo/Treinamento-Data-Science | 5117975109695b1de06ae43b416972e66a4b7773 | [
"MIT"
] | null | null | null | speed_of_light_in_nanosecond_with_vars.py | jjtoledo/Treinamento-Data-Science | 5117975109695b1de06ae43b416972e66a4b7773 | [
"MIT"
] | null | null | null | # Write Python code that stores the distance
# in meters that light travels in one
# nanosecond in the variable, nanodistance.
# These variables are defined for you:
speed_of_light = 299800000. # meters per second
nano_per_sec = 1000000000. # 1 billion
# After your code, running the following:
# print nanodistan... | 22 | 50 | 0.772727 |
7966d349c19862890f1670b98adaf68bda03aed9 | 5,012 | py | Python | src/reportlab/lib/PyFontify.py | nakagami/reportlab | 0514ba380fe66c76746725cc0c1b7a3fee51c833 | [
"BSD-3-Clause"
] | 9 | 2016-12-21T02:19:24.000Z | 2021-08-07T11:39:47.000Z | src/reportlab/lib/PyFontify.py | nakagami/reportlab | 0514ba380fe66c76746725cc0c1b7a3fee51c833 | [
"BSD-3-Clause"
] | null | null | null | src/reportlab/lib/PyFontify.py | nakagami/reportlab | 0514ba380fe66c76746725cc0c1b7a3fee51c833 | [
"BSD-3-Clause"
] | 4 | 2018-08-24T14:50:14.000Z | 2022-03-01T08:46:40.000Z | #Copyright ReportLab Europe Ltd. 2000-2012
#see license.txt for license details
__version__=''' $Id: PyFontify.py 3959 2012-09-27 14:39:39Z robin $ '''
__doc__="""
Module to analyze Python source code; for syntax coloring tools.
Interface::
tags = fontify(pytext, searchfrom, searchto)
- The 'pytext' argument is... | 31.130435 | 90 | 0.565842 |
7966d3eadef26d069d7154b4edbf18f35b52e759 | 501,584 | py | Python | ns-3-dev-git/src/lr-wpan/bindings/modulegen__gcc_LP64.py | rahul0324/Upgrade-AQM-Evaluation-Suite-of-ns-3 | 9d46441749da1059b2e9525d72fce61cb0e42150 | [
"MIT"
] | 1 | 2022-03-23T13:55:42.000Z | 2022-03-23T13:55:42.000Z | ns-3-dev-git/src/lr-wpan/bindings/modulegen__gcc_LP64.py | rahulkumdas/Upgrade-AQM-Evaluation-Suite-of-ns-3 | 9d46441749da1059b2e9525d72fce61cb0e42150 | [
"MIT"
] | null | null | null | ns-3-dev-git/src/lr-wpan/bindings/modulegen__gcc_LP64.py | rahulkumdas/Upgrade-AQM-Evaluation-Suite-of-ns-3 | 9d46441749da1059b2e9525d72fce61cb0e42150 | [
"MIT"
] | null | null | null | from pybindgen import Module, FileCodeSink, param, retval, cppclass, typehandlers
import pybindgen.settings
import warnings
class ErrorHandler(pybindgen.settings.ErrorHandler):
def handle_error(self, wrapper, exception, traceback_):
warnings.warn("exception %r in wrapper %s" % (exception, wrapper))
... | 69.65477 | 482 | 0.640527 |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.